@@ -17,34 +17,24 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+/*
+ * This file is part of LibreOffice published API.
+ */
+
 #ifndef INCLUDED_SAL_TYPES_H
 #define INCLUDED_SAL_TYPES_H
 
-#include <sal/config.h>
+#include "sal/config.h"
 
 #include <stddef.h>
 
-#include <sal/macros.h>
-#include <sal/typesizes.h>
+#include "sal/macros.h"
+#include "sal/typesizes.h"
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#if defined ( __MINGW32__ ) && !defined ( __USE_MINGW_ANSI_STDIO )
-/* Define to use the C99 formatting string for coherence reasons.
- * In mingw-w64 some functions are ported to the ms formatting string
- * some are not yet. This is the only way to make the formatting
- * strings work all the time
- */
-#define __USE_MINGW_ANSI_STDIO 1
-#endif
-
-/********************************************************************************/
-/* Data types
-*/
-
-/* Boolean */
 typedef unsigned char sal_Bool;
 #   define sal_False ((sal_Bool)0)
 #   define sal_True  ((sal_Bool)1)
@@ -120,36 +110,17 @@ typedef unsigned char       sal_uInt8;
         #error "Could not find 64-bit type, add support for your architecture"
     #endif
 #else
-    #error "Please define the 64-bit types for your architecture/compiler in sal/inc/sal/types.h"
+    #error "Please define the 64-bit types for your architecture/compiler in include/sal/types.h"
 #endif
 
-/** A legacy synonym for `char`.
-
-    @deprecated use plain `char` instead.
-*/
-typedef char sal_Char;
-
-/** A legacy synonym for `signed char`.
-
-    @deprecated use plain `signed char` instead.
-*/
-typedef signed char sal_sChar;
-
-/** A legacy synonym for `unsigned char`.
-
-    @deprecated use plain `unsigned char` instead.
-*/
-typedef unsigned char sal_uChar;
-
-#if ( defined(SAL_W32) && !defined(__MINGW32__) )
-    // http://msdn.microsoft.com/en-us/library/s3f49ktz%28v=vs.80%29.aspx
-    // "By default wchar_t is a typedef for unsigned short."
-    // But MinGW has a native wchar_t, and on many places, we cannot deal with
-    // that, so sal_Unicode has to be explicitly typedef'd as sal_uInt16 there.
-    typedef wchar_t             sal_Unicode;
+#if defined LIBO_INTERNAL_ONLY && defined __cplusplus
+    #define SAL_UNICODE_NOTEQUAL_WCHAR_T
+    typedef char16_t sal_Unicode;
+#elif defined(_WIN32)
+    typedef wchar_t sal_Unicode;
 #else
     #define SAL_UNICODE_NOTEQUAL_WCHAR_T
-    typedef sal_uInt16          sal_Unicode;
+    typedef sal_uInt16 sal_Unicode;
 #endif
 
 typedef void *                   sal_Handle;
@@ -205,10 +176,6 @@ typedef void *                   sal_Handle;
     #error "Please make sure SAL_TYPES_SIZEOFPOINTER is defined for your architecture/compiler"
 #endif
 
-/********************************************************************************/
-/* Useful defines
- */
-
 /* The following SAL_MIN_INTn defines codify the assumption that the signed
  * sal_Int types use two's complement representation.  Defining them as
  * "-0x7F... - 1" instead of as "-0x80..." prevents warnings about applying the
@@ -227,44 +194,52 @@ typedef void *                   sal_Handle;
 #define SAL_MAX_INT64         ((sal_Int64)  SAL_CONST_INT64(0x7FFFFFFFFFFFFFFF))
 #define SAL_MAX_UINT64        ((sal_uInt64) SAL_CONST_UINT64(0xFFFFFFFFFFFFFFFF))
 
-#if SAL_TYPES_SIZEOFLONG == 4
+#if SAL_TYPES_SIZEOFPOINTER == 4
 #define SAL_MAX_SSIZE       SAL_MAX_INT32
 #define SAL_MAX_SIZE        SAL_MAX_UINT32
-#elif SAL_TYPES_SIZEOFLONG == 8
+#elif SAL_TYPES_SIZEOFPOINTER == 8
 #define SAL_MAX_SSIZE       SAL_MAX_INT64
 #define SAL_MAX_SIZE        SAL_MAX_UINT64
 #endif
 
-#if defined(SAL_W32) || defined(SAL_UNX)
-#   define SAL_MAX_ENUM 0x7fffffff
-#endif
+#define SAL_MAX_ENUM 0x7fffffff
 
-#if defined(_MSC_VER) || defined(__MINGW32__)
+#if defined(_MSC_VER)
 #   define SAL_DLLPUBLIC_EXPORT    __declspec(dllexport)
 #   define SAL_JNI_EXPORT          __declspec(dllexport)
-#if defined(_MSC_VER)
 #   define SAL_DLLPUBLIC_IMPORT    __declspec(dllimport)
-#else
-#   define SAL_DLLPUBLIC_IMPORT
-#endif // defined(_MSC_VER)
 #   define SAL_DLLPRIVATE
 #   define SAL_DLLPUBLIC_TEMPLATE
+#   define SAL_DLLPUBLIC_RTTI
 #   define SAL_CALL         __cdecl
-#   define SAL_CALL_ELLIPSE __cdecl
 #elif defined SAL_UNX
-#   if defined(__GNUC__) && defined(HAVE_GCC_VISIBILITY_FEATURE)
+#   if defined(__GNUC__)
 #     if defined(DISABLE_DYNLOADING)
 #       define SAL_DLLPUBLIC_EXPORT  __attribute__ ((visibility("hidden")))
 #       define SAL_JNI_EXPORT        __attribute__ ((visibility("default")))
 #       define SAL_DLLPUBLIC_IMPORT  __attribute__ ((visibility("hidden")))
 #       define SAL_DLLPRIVATE        __attribute__ ((visibility("hidden")))
 #       define SAL_DLLPUBLIC_TEMPLATE __attribute__ ((visibility("hidden")))
+#       define SAL_DLLPUBLIC_RTTI     __attribute__ ((visibility("default")))
 #     else
 #       define SAL_DLLPUBLIC_EXPORT  __attribute__ ((visibility("default")))
 #       define SAL_JNI_EXPORT        __attribute__ ((visibility("default")))
 #       define SAL_DLLPUBLIC_IMPORT  __attribute__ ((visibility("default")))
 #       define SAL_DLLPRIVATE        __attribute__ ((visibility("hidden")))
 #       define SAL_DLLPUBLIC_TEMPLATE __attribute__ ((visibility("default")))
+#       if defined __clang__
+#         if __has_attribute(type_visibility)
+#           define SAL_DLLPUBLIC_RTTI  __attribute__ ((type_visibility("default")))
+#         else
+#           define SAL_DLLPUBLIC_RTTI  __attribute__ ((visibility("default")))
+#         endif
+#       else
+// GCC does not have currently have equivalent functionality to clang's type_visibility
+// but I have a feature request for that at https://gcc.gnu.org/bugzilla/show_bug.cgi?id=113958
+// Until that is implemented, just make the whole class visible, which is what I would need to
+// do anyhow if something wants to import the typeinfo symbol.
+#         define SAL_DLLPUBLIC_RTTI  __attribute__ ((visibility("default")))
+#       endif
 #     endif
 #   else
 #     define SAL_DLLPUBLIC_EXPORT
@@ -272,9 +247,9 @@ typedef void *                   sal_Handle;
 #     define SAL_DLLPUBLIC_IMPORT
 #     define SAL_DLLPRIVATE
 #     define SAL_DLLPUBLIC_TEMPLATE
+#     define SAL_DLLPUBLIC_RTTI
 #   endif
 #   define SAL_CALL
-#   define SAL_CALL_ELLIPSE
 #else
 #   error("unknown platform")
 #endif
@@ -285,7 +260,7 @@ typedef void *                   sal_Handle;
    These macros are used for inline declarations of exception classes, as in
    rtl/malformeduriexception.hxx.
 */
-#if defined(__GNUC__) && ! defined(__MINGW32__)
+#if defined(__GNUC__)
 #   if defined(DISABLE_DYNLOADING)
 #      define SAL_EXCEPTION_DLLPUBLIC_EXPORT __attribute__((visibility("default")))
 #    else
@@ -298,17 +273,35 @@ typedef void *                   sal_Handle;
 #endif
 
 /** Use this as markup for functions and methods whose return value must be
-    checked.
+    used.
 
     Compilers that support a construct of this nature will emit a compile
-    time warning on unchecked return value.
+    time warning on unused return value.
 */
-#if (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 1))
+#if defined LIBO_INTERNAL_ONLY && defined __cplusplus
+#define SAL_WARN_UNUSED_RESULT [[nodiscard]]
+#elif (defined __GNUC__ \
+     && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 1))) \
+    || defined __clang__
 #   define SAL_WARN_UNUSED_RESULT __attribute__((warn_unused_result))
 #else
 #   define SAL_WARN_UNUSED_RESULT
 #endif
 
+#if defined LIBO_INTERNAL_ONLY
+/** Use this as markup for functions and methods whose return value may be
+    null and should not be dereferenced unconditionally.
+
+    Compilers that support a construct of this nature will emit a compile
+    time warning on unconditional dereference of returned pointer.
+*/
+#ifdef _MSC_VER
+#   define SAL_RET_MAYBENULL _Ret_maybenull_
+#else
+#   define SAL_RET_MAYBENULL
+#endif
+#endif
+
 /** Use this for pure virtual classes, e.g. class SAL_NO_VTABLE Foo { ...
     This hinders the compiler from setting a generic vtable stating that
     a pure virtual function was called and thus slightly reduces code size.
@@ -319,12 +312,11 @@ typedef void *                   sal_Handle;
 #   define SAL_NO_VTABLE
 #endif
 
-#ifdef SAL_W32
+#ifdef _WIN32
 #   pragma pack(push, 8)
 #endif
 
 /** This is the binary specification of a SAL sequence.
-    <br>
 */
 typedef struct _sal_Sequence
 {
@@ -341,30 +333,40 @@ typedef struct _sal_Sequence
 
 #define SAL_SEQUENCE_HEADER_SIZE ((sal_Size) offsetof(sal_Sequence,elements))
 
-#if defined( SAL_W32)
+#if defined( _WIN32)
 #pragma pack(pop)
 #endif
 
-#if defined __cplusplus
-
-/** Nothrow specification for C functions.
-
-    This is a macro so it can expand to nothing in C code.
-*/
-#define SAL_THROW_EXTERN_C() throw ()
-
-#else
-
-#define SAL_THROW_EXTERN_C()
-
-#endif
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
 
+/** Nothrow specification for C functions.
+
+    This is a macro so it can expand to nothing in C code.
+*/
+#if defined __cplusplus
+#if __cplusplus >= 201103L
+#define SAL_THROW_EXTERN_C() noexcept
+#else
+#define SAL_THROW_EXTERN_C() throw ()
+#endif
+#else
+#define SAL_THROW_EXTERN_C()
+#endif
+
 #ifdef __cplusplus
 
+/** To markup destructors that coverity warns might throw exceptions
+    which won't throw in practice, or where std::terminate is
+    an acceptable response if they do
+*/
+#if defined(LIBO_INTERNAL_ONLY) && defined(__COVERITY__)
+#   define COVERITY_NOEXCEPT_FALSE noexcept(false)
+#else
+#   define COVERITY_NOEXCEPT_FALSE
+#endif
+
 enum __sal_NoAcquire
 {
     /** definition of a no acquire enum for ctors
@@ -382,13 +384,13 @@ namespace css = ::com::sun::star;
 
 /** C++11 "= delete" feature.
 
-    With HAVE_CXX11_DELETE, calling a deleted function will cause a compile-time
+    For LIBO_INTERNAL_ONLY, calling a deleted function will cause a compile-time
     error, while otherwise it will only cause a link-time error as the declared
     function is not defined.
 
     @since LibreOffice 4.1
 */
-#if HAVE_CXX11_DELETE
+#if defined LIBO_INTERNAL_ONLY
 #define SAL_DELETED_FUNCTION = delete
 #else
 #define SAL_DELETED_FUNCTION
@@ -396,27 +398,40 @@ namespace css = ::com::sun::star;
 
 /** C++11 "override" feature.
 
-    With HAVE_CXX11_OVERRIDE, force the method to override a existing method in
+    For LIBO_INTERNAL_ONLY, force the method to override an existing method in
     parent, error out if the method with the correct signature does not exist.
 
     @since LibreOffice 4.1
 */
-#if HAVE_CXX11_OVERRIDE
+#if defined LIBO_INTERNAL_ONLY
 #define SAL_OVERRIDE override
 #else
 #define SAL_OVERRIDE
 #endif
 
-/** C++11 "final" feature.
+/** C++11 "constexpr" feature.
 
-    With HAVE_CXX11_FINAL, mark a class as non-derivable or a method as non-overridable.
+    For LIBO_INTERNAL_ONLY, declare that it's possible to evaluate the value
+    at compile time.
 
-    @since LibreOffice 4.1
+    @since LibreOffice 7.2
 */
-#if HAVE_CXX11_FINAL
-#define SAL_FINAL final
+#if defined LIBO_INTERNAL_ONLY
+#define SAL_CONSTEXPR constexpr
 #else
-#define SAL_FINAL
+#define SAL_CONSTEXPR
+#endif
+
+/** Macro for C++11 "noexcept" vs. "throw ()" exception specification.
+
+    The latter has been removed completely from C++20.
+
+    @since LibreOffice 7.2
+ */
+#if __cplusplus >= 201103L
+#define SAL_NOEXCEPT noexcept
+#else
+#define SAL_NOEXCEPT throw ()
 #endif
 
 #endif /* __cplusplus */
@@ -462,13 +477,15 @@ template< typename T1, typename T2 > inline T1 static_int_cast(T2 n) {
 
 /**
     Use as follows:
-        SAL_DEPRECATED("Dont use, its evil.") void doit(int nPara);
+        SAL_DEPRECATED("Don't use, it's evil.") void doit(int nPara);
 */
 
-#if HAVE_GCC_DEPRECATED_MESSAGE
+#if defined __GNUC__ || defined __clang__
+#if defined LIBO_INTERNAL_ONLY
 #    define SAL_DEPRECATED(message) __attribute__((deprecated(message)))
-#elif (__GNUC__)
+#else
 #    define SAL_DEPRECATED(message) __attribute__((deprecated))
+#endif
 #elif defined(_MSC_VER)
 #    define SAL_DEPRECATED(message) __declspec(deprecated(message))
 #else
@@ -476,13 +493,15 @@ template< typename T1, typename T2 > inline T1 static_int_cast(T2 n) {
 #endif
 
 /**
-   This macro is used to tag interfaces that are deprecated for both
-   internal and external API users, but where we are still writing
-   out the internal usage. Ultimately these should be replaced by
-   SAL_DEPRECATED, and then removed.
+   This macro is used in cppumaker-generated include files, to tag entities that
+   are marked as @deprecated in UNOIDL.
 
-   Use as follows:
-        SAL_DEPRECATED_INTERNAL("Dont use, its evil.") void doit(int nPara);
+   It causes deprecation warnings to be generated in external code, but for now
+   is silenced in internal code.  It would need some substantial clean-up of
+   internal code to fix all warnings/errors generated by it.  (Once that is
+   done, it can become a synonym for SAL_DEPRECATED under LIBO_INTERNAL_ONLY,
+   too.  Completely removing the macro then would be incompatible, in case there
+   are include files still around generated with a cppumaker that emitted it.)
  */
 #ifdef LIBO_INTERNAL_ONLY
 #    define SAL_DEPRECATED_INTERNAL(message)
@@ -497,12 +516,18 @@ template< typename T1, typename T2 > inline T1 static_int_cast(T2 n) {
         SAL_WNODEPRECATED_DECLARATIONS_POP
 */
 
-#if HAVE_GCC_PRAGMA_OPERATOR
+#if defined LIBO_INTERNAL_ONLY && defined __GNUC__
 #define SAL_WNODEPRECATED_DECLARATIONS_PUSH \
     _Pragma(SAL_STRINGIFY_ARG(GCC diagnostic push)) \
     _Pragma(SAL_STRINGIFY_ARG(GCC diagnostic ignored "-Wdeprecated-declarations"))
 #define SAL_WNODEPRECATED_DECLARATIONS_POP \
     _Pragma(SAL_STRINGIFY_ARG(GCC diagnostic pop))
+#elif defined LIBO_INTERNAL_ONLY && defined _MSC_VER
+#define SAL_WNODEPRECATED_DECLARATIONS_PUSH \
+    _Pragma(SAL_STRINGIFY_ARG(warning(push))) \
+    _Pragma(SAL_STRINGIFY_ARG(warning(disable : 4996)))
+#define SAL_WNODEPRECATED_DECLARATIONS_POP \
+    _Pragma(SAL_STRINGIFY_ARG(warning(pop)))
 #else
 #   define SAL_WNODEPRECATED_DECLARATIONS_PUSH
 #   define SAL_WNODEPRECATED_DECLARATIONS_POP
@@ -519,7 +544,7 @@ template< typename T1, typename T2 > inline T1 static_int_cast(T2 n) {
 
    Useful in cases where the compiler is "too clever" like when doing
    link-time code generation, and noticing that a called function
-   always throws, and fixing the problem cleanly so that it produceds
+   always throws, and fixing the problem cleanly so that it produces
    no warnings in normal non-LTO compilations either is not easy.
 
 */
@@ -561,7 +586,7 @@ template< typename T1, typename T2 > inline T1 static_int_cast(T2 n) {
     @since LibreOffice 3.6
  */
 #if defined __cplusplus
-#if defined __GNUC__
+#if defined __GNUC__ || defined __clang__
 #define SAL_UNUSED_PARAMETER __attribute__ ((unused))
 #else
 #define SAL_UNUSED_PARAMETER
@@ -580,14 +605,119 @@ template< typename T1, typename T2 > inline T1 static_int_cast(T2 n) {
 
 */
 
-#if HAVE_GCC_ATTRIBUTE_WARN_UNUSED
+#if defined LIBO_INTERNAL_ONLY && (defined __GNUC__ || defined __clang__)
 #define SAL_WARN_UNUSED __attribute__((warn_unused))
-#elif defined __clang__
-#define SAL_WARN_UNUSED __attribute__((annotate("lo_warn_unused")))
 #else
 #define SAL_WARN_UNUSED
 #endif
 
+/// @cond INTERNAL
+
+#if defined __GNUC__ || defined __clang__
+// Macro to try to catch and warn on assignments inside expr.
+#    define SAL_DETAIL_BOOLEAN_EXPR(expr)   \
+        __extension__ ({                    \
+            int sal_boolean_var_;           \
+            if (expr)                       \
+               sal_boolean_var_ = 1;        \
+            else                            \
+               sal_boolean_var_ = 0;        \
+            sal_boolean_var_;               \
+        })
+
+/** An optimization annotation: denotes that expression is likely to be true.
+
+    Use it to annotate paths that we think are likely eg.
+    if (SAL_LIKELY(ptr != nullptr))
+       // this path is the one that is ~always taken.
+
+    @since LibreOffice 5.2
+
+    Returns: the boolean value of expr (expressed as either int 1 or 0)
+ */
+#    define SAL_LIKELY(expr) __builtin_expect(SAL_DETAIL_BOOLEAN_EXPR((expr)), 1)
+
+/** An optimization annotation: denotes that expression is unlikely to be true.
+
+    Use it to annotate paths that we think are likely eg.
+    if (SAL_UNLIKELY(ptr != nullptr))
+       // this path is the one that is ~never taken.
+
+    @since LibreOffice 5.2
+
+    Returns: the boolean value of expr (expressed as either int 1 or 0)
+ */
+#    define SAL_UNLIKELY(expr) __builtin_expect(SAL_DETAIL_BOOLEAN_EXPR((expr)), 0)
+
+/** An optimization annotation: tells the compiler to work harder at this code
+
+    If the SAL_HOT annotation is present on a function or a label then
+    subsequent code statements may have more aggressive compiler
+    optimization and in-lining work performed on them.
+
+    In addition this code can end up in a special section, to be
+    grouped with other frequently used code.
+
+    @since LibreOffice 5.2
+ */
+#    define SAL_HOT __attribute__((hot))
+
+/** An optimization annotation: tells the compiler to work less on this code
+
+    If the SAL_COLD annotation is present on a function or a label then
+    subsequent code statements are unlikely to be performed except in
+    exceptional circumstances, and optimizing for code-size rather
+    than performance is preferable.
+
+    In addition this code can end up in a special section, to be grouped
+    with (and away from) other more frequently used code, to improve
+    locality of reference.
+
+    @since LibreOffice 5.2
+ */
+#    define SAL_COLD __attribute__((cold))
+#else
+#    define SAL_LIKELY(expr) (expr)
+#    define SAL_UNLIKELY(expr) (expr)
+#    define SAL_HOT
+#    define SAL_COLD
+#endif
+
+/// @endcond
+
+/// @cond INTERNAL
+/** Annotate pointer-returning functions to indicate that such a pointer
+    is never nullptr.
+
+    Note that MSVC supports this feature via it's SAL _Ret_notnull_
+    annotation, but since it's in a completely different place on
+    the function declaration, it's a little hard to support both.
+
+    @since LibreOffice 5.5
+*/
+#ifndef __has_attribute
+#define __has_attribute(x) 0
+#endif
+
+#if defined LIBO_INTERNAL_ONLY && ((defined __GNUC__ && !defined __clang__) || (defined __clang__ && __has_attribute(returns_nonnull)))
+#define SAL_RETURNS_NONNULL  __attribute__((returns_nonnull))
+#else
+#define SAL_RETURNS_NONNULL
+#endif
+/// @endcond
+
+#if defined LIBO_INTERNAL_ONLY
+// An annotation mechanism used by some loplugins.  The id argument must be an ordinary string
+// literal.  For Clang, this expands to a clang::annotate attribute with an annotation consisting of
+// the concatenation of a "loplugin:" prefix and the given id suffix.  For non-Clang, this expands
+// to nothing to avoid e.g. -Wattributes from GCC's -Wall.
+#if defined __clang__
+#define SAL_LOPLUGIN_ANNOTATE(id) [[clang::annotate("loplugin:" id)]]
+#else
+#define SAL_LOPLUGIN_ANNOTATE(id)
+#endif
+#endif
+
 #endif // INCLUDED_SAL_TYPES_H
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
