@@ -50,13 +50,13 @@ var searchData=
   ['e_5fxdev_47',['E_XDEV',['../a00774.html#ae2e12b95c2df5b6cab62104982151c7ea49882afe072f47c78ab529fda217831e',1,'osl::FileBase']]],
   ['element_5falias_48',['element_alias',['../a01854.html',1,'cppu::detail::element_alias'],['../a01854.html#ac2f276cf00b43edc7b8a8158e78f8d50',1,'cppu::detail::element_alias::element_alias()']]],
   ['elements_49',['elements',['../a00550.html#a847f65188738a4903d32b37863231285',1,'_sal_Sequence']]],
-  ['elementtype_50',['ElementType',['../a01010.html#aeba6ad4a5e51a594191532a4a171f9db',1,'com::sun::star::uno::Sequence']]],
+  ['elementtype_50',['ElementType',['../a01010.html#aeba6ad4a5e51a594191532a4a171f9db',1,'com::sun::star::uno::Sequence::ElementType'],['../a01010.html#aeba6ad4a5e51a594191532a4a171f9db',1,'com::sun::star::uno::Sequence&lt; bool &gt;::ElementType']]],
   ['enable_51',['Enable',['../a00726.html',1,'rtl::libreoffice_internal']]],
-  ['enable_3c_20t_2c_20true_20_3e_52',['Enable&lt; T, true &gt;',['../a00726.html',1,'rtl::libreoffice_internal']]],
+  ['enable_3c_20t_2c_20true_20_3e_52',['Enable&lt; T, true &gt;',['../a00730.html',1,'rtl::libreoffice_internal']]],
   ['enablechangelistenernotification_53',['enableChangeListenerNotification',['../a01926.html#a01ee4368d1b29b8610baad98a3097cec',1,'cppu::OPropertySetHelper2']]],
   ['enablenonblockingmode_54',['enableNonBlockingMode',['../a00858.html#ada1ee513556e62e7058c522992ffcf13',1,'osl::Socket']]],
   ['encode_55',['encode',['../a00610.html#a1e84db69fd5b4b86a6a92b1eb547adb6',1,'rtl::Bootstrap::encode()'],['../a00746.html#acb69b2efad453d22779fe5ffa6d8f2a6',1,'rtl::Uri::encode(rtl::OUString const &amp;rText, sal_Bool const *pCharClass, rtl_UriEncodeMechanism eMechanism, rtl_TextEncoding eCharset)'],['../a00746.html#a448fa7e0d5403c180c1f59cae1867e77',1,'rtl::Uri::encode(rtl::OUString const &amp;rText, rtl_UriCharClass eCharClass, rtl_UriEncodeMechanism eMechanism, rtl_TextEncoding eCharset)']]],
-  ['end_56',['end',['../a01010.html#a6aa569da57fb65c4b001fec1e80fe902',1,'com::sun::star::uno::Sequence::end()'],['../a01010.html#aa6765e6c72caadf94d802a3f6280f770',1,'com::sun::star::uno::Sequence::end() const']]],
+  ['end_56',['end',['../a01010.html#a6aa569da57fb65c4b001fec1e80fe902',1,'com::sun::star::uno::Sequence::end()'],['../a01010.html#aa6765e6c72caadf94d802a3f6280f770',1,'com::sun::star::uno::Sequence::end() const'],['../a01010.html#a6aa569da57fb65c4b001fec1e80fe902',1,'com::sun::star::uno::Sequence&lt; bool &gt;::end()']]],
   ['endian_2eh_57',['endian.h',['../a00197.html',1,'']]],
   ['endswith_58',['endsWith',['../a00666.html#ae74d8d826f8bb6590454135348454f85',1,'rtl::OString::endsWith(OString const &amp;str, OString *rest=NULL) const'],['../a00666.html#a124086ebe8d9159db2c703b030961ee6',1,'rtl::OString::endsWith(T &amp;literal, OString *rest=NULL) const'],['../a00754.html#a0a9dd4283c1651c8e0261077273d48dc',1,'rtl::OUString::endsWith(OUString const &amp;str, OUString *rest=NULL) const'],['../a00754.html#abd00c579b6f686891f4aa7d73f38c873',1,'rtl::OUString::endsWith(T &amp;literal, OUString *rest=NULL) const']]],
   ['endswithasciil_59',['endsWithAsciiL',['../a00754.html#a1dce9523dbc575f14cd2212cef2ddcdc',1,'rtl::OUString']]],
