@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['wait_0',['wait',['../a00878.html#ac51d11d3729116f912934ffefe9ad2d6',1,'osl::Thread::wait()'],['../a00762.html#a9d777609e20094558e76e528c1b15e2e',1,'osl::Condition::wait()']]],
+  ['wait_0',['wait',['../a00762.html#a9d777609e20094558e76e528c1b15e2e',1,'osl::Condition::wait()'],['../a00878.html#ac51d11d3729116f912934ffefe9ad2d6',1,'osl::Thread::wait()'],['../a00598.html#ac51d11d3729116f912934ffefe9ad2d6',1,'salhelper::Thread::wait()']]],
   ['weakaggcomponentimplhelper1_1',['WeakAggComponentImplHelper1',['../a01050.html#a539345db80771d0ee7e8845f2c022f57',1,'cppu::WeakAggComponentImplHelper1']]],
   ['weakaggcomponentimplhelper10_2',['WeakAggComponentImplHelper10',['../a01074.html#a93425dffcbdc8953790144cfb20f18d4',1,'cppu::WeakAggComponentImplHelper10']]],
   ['weakaggcomponentimplhelper11_3',['WeakAggComponentImplHelper11',['../a01098.html#adbc203e7235e02bf44917c243de7b126',1,'cppu::WeakAggComponentImplHelper11']]],
@@ -25,8 +25,8 @@ var searchData=
   ['weakcomponentimplhelper7_22',['WeakComponentImplHelper7',['../a01250.html#a9a75352a4e9e3ae6be026fd9a78199bc',1,'cppu::WeakComponentImplHelper7']]],
   ['weakcomponentimplhelper8_23',['WeakComponentImplHelper8',['../a01274.html#a4075189c6c233e3e9229b0ff89214962',1,'cppu::WeakComponentImplHelper8']]],
   ['weakcomponentimplhelper9_24',['WeakComponentImplHelper9',['../a01298.html#a8c7f2a294a7da3502627c1579fca711c',1,'cppu::WeakComponentImplHelper9']]],
-  ['weakreference_25',['weakreference',['../a01958.html#a81c6ea589549e79c3f826cccee911c96',1,'com::sun::star::uno::WeakReference::WeakReference()'],['../a01958.html#acaf481b6213b80c061daf01407e848c2',1,'com::sun::star::uno::WeakReference::WeakReference(const Reference&lt; interface_type &gt; &amp;rRef)']]],
-  ['weakreferencehelper_26',['weakreferencehelper',['../a01954.html#a4dee9f907ba07214463819d756726182',1,'com::sun::star::uno::WeakReferenceHelper::WeakReferenceHelper(const WeakReferenceHelper &amp;rWeakRef)'],['../a01954.html#a01c610f0b6dc26c7a66caf6878a51bd5',1,'com::sun::star::uno::WeakReferenceHelper::WeakReferenceHelper(const css::uno::Reference&lt; css::uno::XInterface &gt; &amp;xInt)'],['../a01954.html#aca4edf16679e5f81ed2bef368a4f4d63',1,'com::sun::star::uno::WeakReferenceHelper::WeakReferenceHelper()']]],
+  ['weakreference_25',['WeakReference',['../a01958.html#a81c6ea589549e79c3f826cccee911c96',1,'com::sun::star::uno::WeakReference::WeakReference()'],['../a01958.html#acaf481b6213b80c061daf01407e848c2',1,'com::sun::star::uno::WeakReference::WeakReference(const Reference&lt; interface_type &gt; &amp;rRef)']]],
+  ['weakreferencehelper_26',['WeakReferenceHelper',['../a01954.html#aca4edf16679e5f81ed2bef368a4f4d63',1,'com::sun::star::uno::WeakReferenceHelper::WeakReferenceHelper()'],['../a01954.html#a4dee9f907ba07214463819d756726182',1,'com::sun::star::uno::WeakReferenceHelper::WeakReferenceHelper(const WeakReferenceHelper &amp;rWeakRef)'],['../a01954.html#a01c610f0b6dc26c7a66caf6878a51bd5',1,'com::sun::star::uno::WeakReferenceHelper::WeakReferenceHelper(const css::uno::Reference&lt; css::uno::XInterface &gt; &amp;xInt)']]],
   ['write_27',['write',['../a00790.html#aaff12dea186b6242260ae8309b6127d0',1,'osl::File::write()'],['../a00834.html#a30cdb06bcd089b1187dc39e88df8caf3',1,'osl::StreamPipe::write()'],['../a00862.html#a728d093e0c39a2c5350b355d85a84be8',1,'osl::StreamSocket::write()']]],
   ['writebool_28',['writeBool',['../a00842.html#a2e91013ff0f6161016cb4dbbd3bf5e11',1,'osl::Profile']]],
   ['writeident_29',['writeIdent',['../a00842.html#af29f27877b179547100689985fd8e14a',1,'osl::Profile']]],
