@@ -37,6 +37,7 @@ var dir_f862b9ba32e9fef56460bf00faa89077 =
     [ "ConditionOperator.idl", "ConditionOperator_8idl.html", "ConditionOperator_8idl" ],
     [ "ConditionOperator2.idl", "ConditionOperator2_8idl.html", "ConditionOperator2_8idl" ],
     [ "ConsolidationDescriptor.idl", "ConsolidationDescriptor_8idl.html", "ConsolidationDescriptor_8idl" ],
+    [ "CreateDialogFactoryService.idl", "sheet_2CreateDialogFactoryService_8idl.html", "sheet_2CreateDialogFactoryService_8idl" ],
     [ "DataBar.idl", "DataBar_8idl.html", "DataBar_8idl" ],
     [ "DataBarAxis.idl", "DataBarAxis_8idl.html", "DataBarAxis_8idl" ],
     [ "DataBarEntryType.idl", "DataBarEntryType_8idl.html", "DataBarEntryType_8idl" ],
@@ -320,6 +321,7 @@ var dir_f862b9ba32e9fef56460bf00faa89077 =
     [ "XSheetOutline.idl", "XSheetOutline_8idl.html", "XSheetOutline_8idl" ],
     [ "XSheetPageBreak.idl", "XSheetPageBreak_8idl.html", "XSheetPageBreak_8idl" ],
     [ "XSheetPastable.idl", "XSheetPastable_8idl.html", "XSheetPastable_8idl" ],
+    [ "XSheetRange.idl", "XSheetRange_8idl.html", "XSheetRange_8idl" ],
     [ "XSolver.idl", "XSolver_8idl.html", "XSolver_8idl" ],
     [ "XSolverDescription.idl", "XSolverDescription_8idl.html", "XSolverDescription_8idl" ],
     [ "XSpreadsheet.idl", "XSpreadsheet_8idl.html", "XSpreadsheet_8idl" ],
