@@ -374,6 +374,7 @@ var namespacecom_1_1sun_1_1star_1_1sheet =
     [ "ConditionalFormat", "servicecom_1_1sun_1_1star_1_1sheet_1_1ConditionalFormat.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1ConditionalFormat" ],
     [ "ConditionFormatEntry", "servicecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatEntry.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatEntry" ],
     [ "ConsolidationDescriptor", "servicecom_1_1sun_1_1star_1_1sheet_1_1ConsolidationDescriptor.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1ConsolidationDescriptor" ],
+    [ "CreateDialogFactoryService", "servicecom_1_1sun_1_1star_1_1sheet_1_1CreateDialogFactoryService.html", null ],
     [ "DataBar", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataBar.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DataBar" ],
     [ "DatabaseImportDescriptor", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseImportDescriptor.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseImportDescriptor" ],
     [ "DatabaseRange", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html", "servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange" ],
@@ -611,6 +612,7 @@ var namespacecom_1_1sun_1_1star_1_1sheet =
     [ "XSheetOutline", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetOutline.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetOutline" ],
     [ "XSheetPageBreak", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetPageBreak.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetPageBreak" ],
     [ "XSheetPastable", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetPastable.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetPastable" ],
+    [ "XSheetRange", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetRange.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetRange" ],
     [ "XSolver", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSolver.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSolver" ],
     [ "XSolverDescription", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSolverDescription.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSolverDescription" ],
     [ "XSpreadsheet", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheet.html", "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheet" ],
