@@ -1,5 +1,31 @@
 var NAVTREEINDEX35 =
 {
+"exceptioncom_1_1sun_1_1star_1_1drawing_1_1GraphicFilterRequest.html#afb9e9132030d0019d218c028a1049888":[3,0,0,0,0,15,51,0],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1InvalidStorageException.html":[2,0,0,0,0,16,20],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1InvalidStorageException.html":[3,0,0,0,0,16,9],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1LinkageMisuseException.html":[2,0,0,0,0,16,21],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1LinkageMisuseException.html":[3,0,0,0,0,16,10],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1NeedsRunningStateException.html":[2,0,0,0,0,16,23],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1NeedsRunningStateException.html":[3,0,0,0,0,16,12],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1NoVisualAreaSizeException.html":[2,0,0,0,0,16,24],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1NoVisualAreaSizeException.html":[3,0,0,0,0,16,13],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1ObjectSaveVetoException.html":[2,0,0,0,0,16,25],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1ObjectSaveVetoException.html":[3,0,0,0,0,16,14],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1StateChangeInProgressException.html":[2,0,0,0,0,16,29],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1StateChangeInProgressException.html":[3,0,0,0,0,16,18],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1StateChangeInProgressException.html#a586b8c04d4ca829b43ece66737bf06c2":[2,0,0,0,0,16,29,0],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1StateChangeInProgressException.html#a586b8c04d4ca829b43ece66737bf06c2":[3,0,0,0,0,16,18,0],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1StorageWrappedTargetException.html":[2,0,0,0,0,16,33],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1StorageWrappedTargetException.html":[3,0,0,0,0,16,22],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1UnreachableStateException.html":[2,0,0,0,0,16,34],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1UnreachableStateException.html":[3,0,0,0,0,16,23],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1UnreachableStateException.html#a4cc2528565cf24ed5445a113492d3655":[2,0,0,0,0,16,34,0],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1UnreachableStateException.html#a4cc2528565cf24ed5445a113492d3655":[3,0,0,0,0,16,23,0],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1UnreachableStateException.html#a9117ff1545df7226782d12e52b6c92c8":[2,0,0,0,0,16,34,1],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1UnreachableStateException.html#a9117ff1545df7226782d12e52b6c92c8":[3,0,0,0,0,16,23,1],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1UseBackupException.html":[2,0,0,0,0,16,35],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1UseBackupException.html":[3,0,0,0,0,16,24],
+"exceptioncom_1_1sun_1_1star_1_1embed_1_1UseBackupException.html#a894e23565e04685be88440bd953428c4":[2,0,0,0,0,16,35,0],
 "exceptioncom_1_1sun_1_1star_1_1embed_1_1UseBackupException.html#a894e23565e04685be88440bd953428c4":[3,0,0,0,0,16,24,0],
 "exceptioncom_1_1sun_1_1star_1_1embed_1_1WrongStateException.html":[2,0,0,0,0,16,38],
 "exceptioncom_1_1sun_1_1star_1_1embed_1_1WrongStateException.html":[3,0,0,0,0,16,27],
@@ -223,31 +249,5 @@ var NAVTREEINDEX35 =
 "exceptioncom_1_1sun_1_1star_1_1sdb_1_1RowSetVetoException.html":[3,0,0,0,0,48,54],
 "exceptioncom_1_1sun_1_1star_1_1sdb_1_1SQLContext.html":[2,0,0,0,0,49,62],
 "exceptioncom_1_1sun_1_1star_1_1sdb_1_1SQLContext.html":[3,0,0,0,0,48,57],
-"exceptioncom_1_1sun_1_1star_1_1sdb_1_1SQLContext.html#a71e06363221950a1b0d13a6dbac570e8":[2,0,0,0,0,49,62,0],
-"exceptioncom_1_1sun_1_1star_1_1sdb_1_1SQLContext.html#a71e06363221950a1b0d13a6dbac570e8":[3,0,0,0,0,48,57,0],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1BatchUpdateException.html":[2,0,0,0,0,50,16],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1BatchUpdateException.html":[3,0,0,0,0,49,0],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1BatchUpdateException.html#a95168819ba4c5c66084bb441cb041124":[2,0,0,0,0,50,16,0],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1BatchUpdateException.html#a95168819ba4c5c66084bb441cb041124":[3,0,0,0,0,49,0,0],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html":[2,0,0,0,0,50,22],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html":[3,0,0,0,0,49,6],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#a11fe9f7adb36d3c6b48badfd7652db7d":[2,0,0,0,0,50,22,0],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#a11fe9f7adb36d3c6b48badfd7652db7d":[3,0,0,0,0,49,6,0],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#a50c659a5f2167dc3eacad0826df35b73":[2,0,0,0,0,50,22,4],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#a50c659a5f2167dc3eacad0826df35b73":[3,0,0,0,0,49,6,4],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#a6b8d0f037d86f7ceb132a59847162ff5":[2,0,0,0,0,50,22,3],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#a6b8d0f037d86f7ceb132a59847162ff5":[3,0,0,0,0,49,6,3],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#acdd417fd0e8049decbcc1b8816c26156":[2,0,0,0,0,50,22,1],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#acdd417fd0e8049decbcc1b8816c26156":[3,0,0,0,0,49,6,1],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#af048898f9c0335b8da05901cd9694bd7":[2,0,0,0,0,50,22,2],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#af048898f9c0335b8da05901cd9694bd7":[3,0,0,0,0,49,6,2],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html":[2,0,0,0,0,50,34],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html":[3,0,0,0,0,49,18],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html#a8ec11ac6067b0e4293052a4a39e925f7":[2,0,0,0,0,50,34,0],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html#a8ec11ac6067b0e4293052a4a39e925f7":[3,0,0,0,0,49,18,0],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html#ac16b6bfa5af4cdf8b7608f732b5654d0":[2,0,0,0,0,50,34,1],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html#ac16b6bfa5af4cdf8b7608f732b5654d0":[3,0,0,0,0,49,18,1],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html#ae19fd9ee413725e701125e924a402a78":[2,0,0,0,0,50,34,2],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html#ae19fd9ee413725e701125e924a402a78":[3,0,0,0,0,49,18,2],
-"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLWarning.html":[2,0,0,0,0,50,35]
+"exceptioncom_1_1sun_1_1star_1_1sdb_1_1SQLContext.html#a71e06363221950a1b0d13a6dbac570e8":[2,0,0,0,0,49,62,0]
 };
