@@ -1,5 +1,31 @@
 var NAVTREEINDEX36 =
 {
+"exceptioncom_1_1sun_1_1star_1_1sdb_1_1SQLContext.html#a71e06363221950a1b0d13a6dbac570e8":[3,0,0,0,0,48,57,0],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1BatchUpdateException.html":[2,0,0,0,0,50,16],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1BatchUpdateException.html":[3,0,0,0,0,49,0],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1BatchUpdateException.html#a95168819ba4c5c66084bb441cb041124":[2,0,0,0,0,50,16,0],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1BatchUpdateException.html#a95168819ba4c5c66084bb441cb041124":[3,0,0,0,0,49,0,0],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html":[2,0,0,0,0,50,22],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html":[3,0,0,0,0,49,6],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#a11fe9f7adb36d3c6b48badfd7652db7d":[2,0,0,0,0,50,22,0],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#a11fe9f7adb36d3c6b48badfd7652db7d":[3,0,0,0,0,49,6,0],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#a50c659a5f2167dc3eacad0826df35b73":[2,0,0,0,0,50,22,4],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#a50c659a5f2167dc3eacad0826df35b73":[3,0,0,0,0,49,6,4],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#a6b8d0f037d86f7ceb132a59847162ff5":[2,0,0,0,0,50,22,3],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#a6b8d0f037d86f7ceb132a59847162ff5":[3,0,0,0,0,49,6,3],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#acdd417fd0e8049decbcc1b8816c26156":[2,0,0,0,0,50,22,1],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#acdd417fd0e8049decbcc1b8816c26156":[3,0,0,0,0,49,6,1],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#af048898f9c0335b8da05901cd9694bd7":[2,0,0,0,0,50,22,2],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1DataTruncation.html#af048898f9c0335b8da05901cd9694bd7":[3,0,0,0,0,49,6,2],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html":[2,0,0,0,0,50,34],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html":[3,0,0,0,0,49,18],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html#a8ec11ac6067b0e4293052a4a39e925f7":[2,0,0,0,0,50,34,0],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html#a8ec11ac6067b0e4293052a4a39e925f7":[3,0,0,0,0,49,18,0],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html#ac16b6bfa5af4cdf8b7608f732b5654d0":[2,0,0,0,0,50,34,1],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html#ac16b6bfa5af4cdf8b7608f732b5654d0":[3,0,0,0,0,49,18,1],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html#ae19fd9ee413725e701125e924a402a78":[2,0,0,0,0,50,34,2],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLException.html#ae19fd9ee413725e701125e924a402a78":[3,0,0,0,0,49,18,2],
+"exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLWarning.html":[2,0,0,0,0,50,35],
 "exceptioncom_1_1sun_1_1star_1_1sdbc_1_1SQLWarning.html":[3,0,0,0,0,49,19],
 "exceptioncom_1_1sun_1_1star_1_1security_1_1AccessControlException.html":[2,0,0,0,0,52,3],
 "exceptioncom_1_1sun_1_1star_1_1security_1_1AccessControlException.html":[3,0,0,0,0,51,0],
@@ -19,8 +45,8 @@ var NAVTREEINDEX36 =
 "exceptioncom_1_1sun_1_1star_1_1security_1_1SecurityInfrastructureException.html":[3,0,0,0,0,51,14],
 "exceptioncom_1_1sun_1_1star_1_1security_1_1SignatureException.html":[2,0,0,0,0,52,18],
 "exceptioncom_1_1sun_1_1star_1_1security_1_1SignatureException.html":[3,0,0,0,0,51,15],
-"exceptioncom_1_1sun_1_1star_1_1sheet_1_1NoConvergenceException.html":[2,0,0,0,0,54,139],
-"exceptioncom_1_1sun_1_1star_1_1sheet_1_1NoConvergenceException.html":[3,0,0,0,0,53,102],
+"exceptioncom_1_1sun_1_1star_1_1sheet_1_1NoConvergenceException.html":[2,0,0,0,0,54,140],
+"exceptioncom_1_1sun_1_1star_1_1sheet_1_1NoConvergenceException.html":[3,0,0,0,0,53,103],
 "exceptioncom_1_1sun_1_1star_1_1system_1_1SystemShellExecuteException.html":[2,0,0,0,0,58,6],
 "exceptioncom_1_1sun_1_1star_1_1system_1_1SystemShellExecuteException.html":[3,0,0,0,0,57,4],
 "exceptioncom_1_1sun_1_1star_1_1system_1_1SystemShellExecuteException.html#a5c6586f12a94f23f381892e477132c0e":[2,0,0,0,0,58,6,0],
@@ -89,10 +115,10 @@ var NAVTREEINDEX36 =
 "exceptioncom_1_1sun_1_1star_1_1task_1_1UnsupportedOverwriteRequest.html":[3,0,0,0,0,59,23],
 "exceptioncom_1_1sun_1_1star_1_1task_1_1UnsupportedOverwriteRequest.html#a7ee9065718e6628dc7791b756fa6c0f9":[2,0,0,0,0,60,23,0],
 "exceptioncom_1_1sun_1_1star_1_1task_1_1UnsupportedOverwriteRequest.html#a7ee9065718e6628dc7791b756fa6c0f9":[3,0,0,0,0,59,23,0],
-"exceptioncom_1_1sun_1_1star_1_1text_1_1InvalidTextContentException.html":[2,0,0,0,0,61,87],
-"exceptioncom_1_1sun_1_1star_1_1text_1_1InvalidTextContentException.html":[3,0,0,0,0,60,52],
-"exceptioncom_1_1sun_1_1star_1_1text_1_1InvalidTextContentException.html#aa5e3ebc2782050a59b0dfc51fbde30c0":[2,0,0,0,0,61,87,0],
-"exceptioncom_1_1sun_1_1star_1_1text_1_1InvalidTextContentException.html#aa5e3ebc2782050a59b0dfc51fbde30c0":[3,0,0,0,0,60,52,0],
+"exceptioncom_1_1sun_1_1star_1_1text_1_1InvalidTextContentException.html":[2,0,0,0,0,61,89],
+"exceptioncom_1_1sun_1_1star_1_1text_1_1InvalidTextContentException.html":[3,0,0,0,0,60,53],
+"exceptioncom_1_1sun_1_1star_1_1text_1_1InvalidTextContentException.html#aa5e3ebc2782050a59b0dfc51fbde30c0":[2,0,0,0,0,61,89,0],
+"exceptioncom_1_1sun_1_1star_1_1text_1_1InvalidTextContentException.html#aa5e3ebc2782050a59b0dfc51fbde30c0":[3,0,0,0,0,60,53,0],
 "exceptioncom_1_1sun_1_1star_1_1ucb_1_1AlreadyInitializedException.html":[2,0,0,0,0,63,13],
 "exceptioncom_1_1sun_1_1star_1_1ucb_1_1AlreadyInitializedException.html":[3,0,0,0,0,62,0],
 "exceptioncom_1_1sun_1_1star_1_1ucb_1_1AuthenticationFallbackRequest.html":[2,0,0,0,0,63,15],
@@ -223,31 +249,5 @@ var NAVTREEINDEX36 =
 "exceptioncom_1_1sun_1_1star_1_1ucb_1_1NameClashResolveRequest.html#a0b45f65ed50c870a5af629d894acf4bc":[3,0,0,0,0,62,90,1],
 "exceptioncom_1_1sun_1_1star_1_1ucb_1_1NameClashResolveRequest.html#a99434d040f4ca8e72247813897271095":[2,0,0,0,0,63,103,0],
 "exceptioncom_1_1sun_1_1star_1_1ucb_1_1NameClashResolveRequest.html#a99434d040f4ca8e72247813897271095":[3,0,0,0,0,62,90,0],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1ResultSetException.html":[2,0,0,0,0,63,125],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1ResultSetException.html":[3,0,0,0,0,62,112],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1ServiceNotFoundException.html":[2,0,0,0,0,63,134],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1ServiceNotFoundException.html":[3,0,0,0,0,62,121],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1URLAuthenticationRequest.html":[2,0,0,0,0,63,152],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1URLAuthenticationRequest.html":[3,0,0,0,0,62,139],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1URLAuthenticationRequest.html#af82bacfe5b6faf0534ae06a9540cb886":[2,0,0,0,0,63,152,0],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1URLAuthenticationRequest.html#af82bacfe5b6faf0534ae06a9540cb886":[3,0,0,0,0,62,139,0],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1UnsupportedCommandException.html":[2,0,0,0,0,63,148],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1UnsupportedCommandException.html":[3,0,0,0,0,62,135],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1UnsupportedDataSinkException.html":[2,0,0,0,0,63,149],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1UnsupportedDataSinkException.html":[3,0,0,0,0,62,136],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1UnsupportedDataSinkException.html#a1343a60d0e9e6df46508cdca59ffc988":[2,0,0,0,0,63,149,0],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1UnsupportedDataSinkException.html#a1343a60d0e9e6df46508cdca59ffc988":[3,0,0,0,0,62,136,0],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1UnsupportedNameClashException.html":[2,0,0,0,0,63,150],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1UnsupportedNameClashException.html":[3,0,0,0,0,62,137],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1UnsupportedNameClashException.html#a0b952ceb2c60d04c96fa7e9d5b4312a8":[2,0,0,0,0,63,150,0],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1UnsupportedNameClashException.html#a0b952ceb2c60d04c96fa7e9d5b4312a8":[3,0,0,0,0,62,137,0],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1UnsupportedOpenModeException.html":[2,0,0,0,0,63,151],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1UnsupportedOpenModeException.html":[3,0,0,0,0,62,138],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1UnsupportedOpenModeException.html#a2ea16839f02a4eb2287e770190225b5f":[2,0,0,0,0,63,151,0],
-"exceptioncom_1_1sun_1_1star_1_1ucb_1_1UnsupportedOpenModeException.html#a2ea16839f02a4eb2287e770190225b5f":[3,0,0,0,0,62,138,0],
-"exceptioncom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1ExecutableDialogException.html":[2,0,0,0,0,64,1,11],
-"exceptioncom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1ExecutableDialogException.html":[3,0,0,0,0,63,0,2],
-"exceptioncom_1_1sun_1_1star_1_1uno_1_1DeploymentException.html":[2,0,0,0,0,65,0],
-"exceptioncom_1_1sun_1_1star_1_1uno_1_1DeploymentException.html":[3,0,0,0,0,64,0],
-"exceptioncom_1_1sun_1_1star_1_1uno_1_1Exception.html":[2,0,0,0,0,65,1]
+"exceptioncom_1_1sun_1_1star_1_1ucb_1_1ResultSetException.html":[2,0,0,0,0,63,125]
 };
