@@ -1,5 +1,39 @@
 var NAVTREEINDEX69 =
 {
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XHyphenator.html#a93736b1fb58afc4e50951ee25ebfb2ca":[3,0,0,0,0,30,30,0],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XHyphenator.html#ae412d7de9391a64863f6dfdac01b9df8":[2,0,0,0,0,30,36,1],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XHyphenator.html#ae412d7de9391a64863f6dfdac01b9df8":[3,0,0,0,0,30,30,1],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XHyphenator.html#afad4d7f34112b09b1cea5459bd9446a3":[2,0,0,0,0,30,36,2],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XHyphenator.html#afad4d7f34112b09b1cea5459bd9446a3":[3,0,0,0,0,30,30,2],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLanguageGuessing.html":[2,0,0,0,0,30,37],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLanguageGuessing.html":[3,0,0,0,0,30,31],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLanguageGuessing.html#a31d016dcb0bf5a7acd58d70dfde60dba":[2,0,0,0,0,30,37,5],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLanguageGuessing.html#a31d016dcb0bf5a7acd58d70dfde60dba":[3,0,0,0,0,30,31,5],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLanguageGuessing.html#a3c92914f8f02270b2d1cf848b2c0d36c":[2,0,0,0,0,30,37,2],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLanguageGuessing.html#a3c92914f8f02270b2d1cf848b2c0d36c":[3,0,0,0,0,30,31,2],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLanguageGuessing.html#a40c523c937ffd34eda0a33b6c02ab6d7":[2,0,0,0,0,30,37,3],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLanguageGuessing.html#a40c523c937ffd34eda0a33b6c02ab6d7":[3,0,0,0,0,30,31,3],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLanguageGuessing.html#a419254fdc94e7911cd53adf5a9690687":[2,0,0,0,0,30,37,4],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLanguageGuessing.html#a419254fdc94e7911cd53adf5a9690687":[3,0,0,0,0,30,31,4],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLanguageGuessing.html#a7b9ca699b6272297814c738f6fe57ea4":[2,0,0,0,0,30,37,0],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLanguageGuessing.html#a7b9ca699b6272297814c738f6fe57ea4":[3,0,0,0,0,30,31,0],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLanguageGuessing.html#afee67fe3494e54b536ff314cbed07f6c":[2,0,0,0,0,30,37,1],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLanguageGuessing.html#afee67fe3494e54b536ff314cbed07f6c":[3,0,0,0,0,30,31,1],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html":[2,0,0,0,0,30,38],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html":[3,0,0,0,0,30,32],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html#a07daac7fe1c763ebdece2e08d8499a90":[2,0,0,0,0,30,38,12],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html#a07daac7fe1c763ebdece2e08d8499a90":[3,0,0,0,0,30,32,12],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html#a329db335878b67bd0b66d7876af6933b":[2,0,0,0,0,30,38,4],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html#a329db335878b67bd0b66d7876af6933b":[3,0,0,0,0,30,32,4],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html#a3df7cf7c81d6cdcf7c8d2a8e71e82b7c":[2,0,0,0,0,30,38,5],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html#a3df7cf7c81d6cdcf7c8d2a8e71e82b7c":[3,0,0,0,0,30,32,5],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html#a47633428216dcfc8aab9b2202a922700":[2,0,0,0,0,30,38,1],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html#a47633428216dcfc8aab9b2202a922700":[3,0,0,0,0,30,32,1],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html#a5751b93f8b1c0bd19c04d811a52dc19f":[2,0,0,0,0,30,38,14],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html#a5751b93f8b1c0bd19c04d811a52dc19f":[3,0,0,0,0,30,32,14],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html#a767977fc6264d754873e39c0d9c7fef2":[2,0,0,0,0,30,38,6],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html#a767977fc6264d754873e39c0d9c7fef2":[3,0,0,0,0,30,32,6],
+"interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html#a802e09df2303529cfb0ca259507a37be":[2,0,0,0,0,30,38,13],
 "interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html#a802e09df2303529cfb0ca259507a37be":[3,0,0,0,0,30,32,13],
 "interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html#a8da960730e348d57b0b0eeaa066c6745":[2,0,0,0,0,30,38,7],
 "interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XLinguProperties.html#a8da960730e348d57b0b0eeaa066c6745":[3,0,0,0,0,30,32,7],
@@ -215,39 +249,5 @@ var NAVTREEINDEX69 =
 "interfacecom_1_1sun_1_1star_1_1logging_1_1XLogger.html#abc28d6e58e458c7c624be5088951ee3d":[3,0,0,0,0,32,10,5],
 "interfacecom_1_1sun_1_1star_1_1logging_1_1XLogger.html#adfe03e739241226614f2c2f02a692ef7":[2,0,0,0,0,32,11,3],
 "interfacecom_1_1sun_1_1star_1_1logging_1_1XLogger.html#adfe03e739241226614f2c2f02a692ef7":[3,0,0,0,0,32,10,3],
-"interfacecom_1_1sun_1_1star_1_1logging_1_1XLoggerPool.html":[2,0,0,0,0,32,12],
-"interfacecom_1_1sun_1_1star_1_1logging_1_1XLoggerPool.html":[3,0,0,0,0,32,11],
-"interfacecom_1_1sun_1_1star_1_1logging_1_1XLoggerPool.html#a3328faa86c52ae79030d1a3e4b468a38":[2,0,0,0,0,32,12,0],
-"interfacecom_1_1sun_1_1star_1_1logging_1_1XLoggerPool.html#a3328faa86c52ae79030d1a3e4b468a38":[3,0,0,0,0,32,11,0],
-"interfacecom_1_1sun_1_1star_1_1logging_1_1XLoggerPool.html#a4982debb4558648962dc14a13e6c676f":[2,0,0,0,0,32,12,1],
-"interfacecom_1_1sun_1_1star_1_1logging_1_1XLoggerPool.html#a4982debb4558648962dc14a13e6c676f":[3,0,0,0,0,32,11,1],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XAuthenticator.html":[2,0,0,0,0,33,7],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XAuthenticator.html":[3,0,0,0,0,33,7],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XAuthenticator.html#aa48c3a88849aeb86633acf396027b685":[2,0,0,0,0,33,7,0],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XAuthenticator.html#aa48c3a88849aeb86633acf396027b685":[3,0,0,0,0,33,7,0],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XAuthenticator.html#ae27e136f7e1ec6907d634bd80e0ac890":[2,0,0,0,0,33,7,1],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XAuthenticator.html#ae27e136f7e1ec6907d634bd80e0ac890":[3,0,0,0,0,33,7,1],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XConnectionListener.html":[2,0,0,0,0,33,8],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XConnectionListener.html":[3,0,0,0,0,33,8],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XConnectionListener.html#acfe9f9b6480b21877d6861bd1354f424":[2,0,0,0,0,33,8,0],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XConnectionListener.html#acfe9f9b6480b21877d6861bd1354f424":[3,0,0,0,0,33,8,0],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XConnectionListener.html#ae87c39da796169476f3eaab5a1528393":[2,0,0,0,0,33,8,1],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XConnectionListener.html#ae87c39da796169476f3eaab5a1528393":[3,0,0,0,0,33,8,1],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html":[2,0,0,0,0,33,9],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html":[3,0,0,0,0,33,9],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#a00533685efc8eefd6feeae97dd0cc491":[2,0,0,0,0,33,9,12],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#a00533685efc8eefd6feeae97dd0cc491":[3,0,0,0,0,33,9,12],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#a0b5830702a02044500cf74500a972a09":[2,0,0,0,0,33,9,7],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#a0b5830702a02044500cf74500a972a09":[3,0,0,0,0,33,9,7],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#a2a58baecb1eb9dde54f75edfb7e829db":[2,0,0,0,0,33,9,9],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#a2a58baecb1eb9dde54f75edfb7e829db":[3,0,0,0,0,33,9,9],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#a5dc60097b1688df4c1dfcb764819c3ec":[2,0,0,0,0,33,9,3],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#a5dc60097b1688df4c1dfcb764819c3ec":[3,0,0,0,0,33,9,3],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#a6126b466ad85318d40556a171065b131":[2,0,0,0,0,33,9,2],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#a6126b466ad85318d40556a171065b131":[3,0,0,0,0,33,9,2],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#a6c8b94f60accd698b11d838ebfb0824e":[2,0,0,0,0,33,9,5],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#a6c8b94f60accd698b11d838ebfb0824e":[3,0,0,0,0,33,9,5],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#a8435cbd7a4dda595164d4ff47d4f4525":[2,0,0,0,0,33,9,11],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#a8435cbd7a4dda595164d4ff47d4f4525":[3,0,0,0,0,33,9,11],
-"interfacecom_1_1sun_1_1star_1_1mail_1_1XMailMessage.html#aad6194cd8c1f847c71483433ddb2197c":[2,0,0,0,0,33,9,0]
+"interfacecom_1_1sun_1_1star_1_1logging_1_1XLoggerPool.html":[2,0,0,0,0,32,12]
 };
