@@ -1,5 +1,39 @@
 var NAVTREEINDEX78 =
 {
+"interfacecom_1_1sun_1_1star_1_1scanner_1_1XScannerManager2.html":[3,0,0,0,0,46,4],
+"interfacecom_1_1sun_1_1star_1_1scanner_1_1XScannerManager2.html#a01d09e1e385b2b205e60a7c3c2718343":[2,0,0,0,0,47,4,0],
+"interfacecom_1_1sun_1_1star_1_1scanner_1_1XScannerManager2.html#a01d09e1e385b2b205e60a7c3c2718343":[3,0,0,0,0,46,4,0],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XAllListener.html":[2,0,0,0,0,48,30],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XAllListener.html":[3,0,0,0,0,47,28],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XAllListener.html#a5dd2eba4e4a1cf426683a91d064addc2":[2,0,0,0,0,48,30,1],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XAllListener.html#a5dd2eba4e4a1cf426683a91d064addc2":[3,0,0,0,0,47,28,1],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XAllListener.html#a91b35667ef07d81bfea5b27f21791289":[2,0,0,0,0,48,30,0],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XAllListener.html#a91b35667ef07d81bfea5b27f21791289":[3,0,0,0,0,47,28,0],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XAllListenerAdapterService.html":[2,0,0,0,0,48,31],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XAllListenerAdapterService.html":[3,0,0,0,0,47,29],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XAllListenerAdapterService.html#a955c01dc9336e768264f03fb491827f4":[2,0,0,0,0,48,31,0],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XAllListenerAdapterService.html#a955c01dc9336e768264f03fb491827f4":[3,0,0,0,0,47,29,0],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XAutomationInvocation.html":[2,0,0,0,0,48,32],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XAutomationInvocation.html":[3,0,0,0,0,47,30],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XAutomationInvocation.html#a14ab7fcdc7d82106638468c5407d9ac5":[2,0,0,0,0,48,32,0],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XAutomationInvocation.html#a14ab7fcdc7d82106638468c5407d9ac5":[3,0,0,0,0,47,30,0],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XAutomationInvocation.html#aaaa488f3f81e551451e90ba52b66a65d":[2,0,0,0,0,48,32,1],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XAutomationInvocation.html#aaaa488f3f81e551451e90ba52b66a65d":[3,0,0,0,0,47,30,1],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html":[2,0,0,0,0,48,33],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html":[3,0,0,0,0,47,31],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a144794471d9fc9bad6b03c77ed3259a2":[2,0,0,0,0,48,33,0],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a144794471d9fc9bad6b03c77ed3259a2":[3,0,0,0,0,47,31,0],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a1f1fcacb8ddd29d2c2350c197fd2b1f1":[2,0,0,0,0,48,33,5],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a1f1fcacb8ddd29d2c2350c197fd2b1f1":[3,0,0,0,0,47,31,5],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a2ad6ee16b9bde87813ddd6e45e2d1812":[2,0,0,0,0,48,33,8],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a2ad6ee16b9bde87813ddd6e45e2d1812":[3,0,0,0,0,47,31,8],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a365dd2e330b51218ece765cf76af4595":[2,0,0,0,0,48,33,1],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a365dd2e330b51218ece765cf76af4595":[3,0,0,0,0,47,31,1],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a48ada6f19d7eab6d86f41d5d8e8d5767":[2,0,0,0,0,48,33,7],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a48ada6f19d7eab6d86f41d5d8e8d5767":[3,0,0,0,0,47,31,7],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a5a4a590358fd90994e6dd725717fdad8":[2,0,0,0,0,48,33,10],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a5a4a590358fd90994e6dd725717fdad8":[3,0,0,0,0,47,31,10],
+"interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a7e39aa6d944576ac138fc56379850060":[2,0,0,0,0,48,33,9],
 "interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a7e39aa6d944576ac138fc56379850060":[3,0,0,0,0,47,31,9],
 "interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a8c528baf37154d347366083f0f816846":[2,0,0,0,0,48,33,12],
 "interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html#a8c528baf37154d347366083f0f816846":[3,0,0,0,0,47,31,12],
@@ -215,39 +249,5 @@ var NAVTREEINDEX78 =
 "interfacecom_1_1sun_1_1star_1_1script_1_1XScriptListener.html#a8cb38b19dce4e8ee113201247859a225":[3,0,0,0,0,47,55,1],
 "interfacecom_1_1sun_1_1star_1_1script_1_1XServiceDocumenter.html":[2,0,0,0,0,48,58],
 "interfacecom_1_1sun_1_1star_1_1script_1_1XServiceDocumenter.html":[3,0,0,0,0,47,56],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XServiceDocumenter.html#a63ebfade5ba975e6ad17dffba9d660ba":[2,0,0,0,0,48,58,4],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XServiceDocumenter.html#a63ebfade5ba975e6ad17dffba9d660ba":[3,0,0,0,0,47,56,4],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XServiceDocumenter.html#aaad92323d94371925a79a181bdc6e003":[2,0,0,0,0,48,58,3],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XServiceDocumenter.html#aaad92323d94371925a79a181bdc6e003":[3,0,0,0,0,47,56,3],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XServiceDocumenter.html#ab878b37945ca59c97b4e8bc946a8ab84":[2,0,0,0,0,48,58,1],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XServiceDocumenter.html#ab878b37945ca59c97b4e8bc946a8ab84":[3,0,0,0,0,47,56,1],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XServiceDocumenter.html#acf2f61ec6ee1f91fd785730e3cdd0e1e":[2,0,0,0,0,48,58,2],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XServiceDocumenter.html#acf2f61ec6ee1f91fd785730e3cdd0e1e":[3,0,0,0,0,47,56,2],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XServiceDocumenter.html#ae4ad9031d36fe47d8af1a1766dcff0d8":[2,0,0,0,0,48,58,0],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XServiceDocumenter.html#ae4ad9031d36fe47d8af1a1766dcff0d8":[3,0,0,0,0,47,56,0],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicAccess.html":[2,0,0,0,0,48,59],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicAccess.html":[3,0,0,0,0,47,57],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicAccess.html#a019c94ae8c95d9b9232470efdefd7966":[2,0,0,0,0,48,59,2],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicAccess.html#a019c94ae8c95d9b9232470efdefd7966":[3,0,0,0,0,47,57,2],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicAccess.html#a287512fb488dbd9343e42b2a560d7b96":[2,0,0,0,0,48,59,1],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicAccess.html#a287512fb488dbd9343e42b2a560d7b96":[3,0,0,0,0,47,57,1],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicAccess.html#ad62737ba6e8ec067e5579a2789793aee":[2,0,0,0,0,48,59,3],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicAccess.html#ad62737ba6e8ec067e5579a2789793aee":[3,0,0,0,0,47,57,3],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicAccess.html#af7dc6fee338e14c464fedd138b097e6f":[2,0,0,0,0,48,59,0],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicAccess.html#af7dc6fee338e14c464fedd138b097e6f":[3,0,0,0,0,47,57,0],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicDialogInfo.html":[2,0,0,0,0,48,60],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicDialogInfo.html":[3,0,0,0,0,47,58],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicDialogInfo.html#a11335e13e50af74108bf926dc1340b4b":[2,0,0,0,0,48,60,1],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicDialogInfo.html#a11335e13e50af74108bf926dc1340b4b":[3,0,0,0,0,47,58,1],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicDialogInfo.html#a6342e157c17eb3d82bd3cbce34748d44":[2,0,0,0,0,48,60,0],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicDialogInfo.html#a6342e157c17eb3d82bd3cbce34748d44":[3,0,0,0,0,47,58,0],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicLibraryInfo.html":[2,0,0,0,0,48,61],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicLibraryInfo.html":[3,0,0,0,0,47,59],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicLibraryInfo.html#a11335e13e50af74108bf926dc1340b4b":[2,0,0,0,0,48,61,4],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicLibraryInfo.html#a11335e13e50af74108bf926dc1340b4b":[3,0,0,0,0,47,59,4],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicLibraryInfo.html#a56d705406e4e8f2c078abcc3cab12ae8":[2,0,0,0,0,48,61,3],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicLibraryInfo.html#a56d705406e4e8f2c078abcc3cab12ae8":[3,0,0,0,0,47,59,3],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicLibraryInfo.html#a66f7f8715390c29004b139fd70b0156c":[2,0,0,0,0,48,61,2],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicLibraryInfo.html#a66f7f8715390c29004b139fd70b0156c":[3,0,0,0,0,47,59,2],
-"interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicLibraryInfo.html#a68648eacb286c242b445d29b1cae1a4d":[2,0,0,0,0,48,61,0]
+"interfacecom_1_1sun_1_1star_1_1script_1_1XServiceDocumenter.html#a63ebfade5ba975e6ad17dffba9d660ba":[2,0,0,0,0,48,58,4]
 };
