@@ -1,5 +1,39 @@
 var NAVTREEINDEX80 =
 {
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDataAccessDescriptorFactory.html#a6c41b3ffcf94de11ed20e662b31fa447":[3,0,0,0,0,48,72,0],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccess.html":[2,0,0,0,0,49,78],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccess.html":[3,0,0,0,0,48,73],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccess.html#a2e4ca24e3394f6aef2a102c919e8e0bc":[2,0,0,0,0,49,78,0],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccess.html#a2e4ca24e3394f6aef2a102c919e8e0bc":[3,0,0,0,0,48,73,0],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccess.html#a842dd8353f7b501c1fc02dd4831e82a8":[2,0,0,0,0,49,78,4],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccess.html#a842dd8353f7b501c1fc02dd4831e82a8":[3,0,0,0,0,48,73,4],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccess.html#aa709f286c2e051a0b5255f0a7adeab15":[2,0,0,0,0,49,78,2],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccess.html#aa709f286c2e051a0b5255f0a7adeab15":[3,0,0,0,0,48,73,2],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccess.html#aaf6ef1784316e09535653e5d40d2c0f3":[2,0,0,0,0,49,78,1],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccess.html#aaf6ef1784316e09535653e5d40d2c0f3":[3,0,0,0,0,48,73,1],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccess.html#ac700fac99123eeaeac2ecc90f9169d6d":[2,0,0,0,0,49,78,3],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccess.html#ac700fac99123eeaeac2ecc90f9169d6d":[3,0,0,0,0,48,73,3],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccessListener.html":[2,0,0,0,0,49,79],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccessListener.html":[3,0,0,0,0,48,74],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccessListener.html#a396220620cc87f61ad64fd36b57abcf8":[2,0,0,0,0,49,79,1],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccessListener.html#a396220620cc87f61ad64fd36b57abcf8":[3,0,0,0,0,48,74,1],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccessListener.html#a594bcd748c5ba79be9fb11fbb1e37f0c":[2,0,0,0,0,49,79,0],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccessListener.html#a594bcd748c5ba79be9fb11fbb1e37f0c":[3,0,0,0,0,48,74,0],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccessListener.html#ad7548b81d2f023e38cdf8c9e55140044":[2,0,0,0,0,49,79,2],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseAccessListener.html#ad7548b81d2f023e38cdf8c9e55140044":[3,0,0,0,0,48,74,2],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseContext.html":[2,0,0,0,0,49,80],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseContext.html":[3,0,0,0,0,48,75],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseContext.html#a129dd133e3d7ef2600cb122d60282288":[2,0,0,0,0,49,80,1],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseContext.html#a129dd133e3d7ef2600cb122d60282288":[3,0,0,0,0,48,75,1],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseContext.html#a47999a93adc719d562fbcf1b6f905366":[2,0,0,0,0,49,80,3],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseContext.html#a47999a93adc719d562fbcf1b6f905366":[3,0,0,0,0,48,75,3],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseContext.html#a7a2fee03a55e1e4354eaea94bdaa4e4d":[2,0,0,0,0,49,80,0],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseContext.html#a7a2fee03a55e1e4354eaea94bdaa4e4d":[3,0,0,0,0,48,75,0],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseContext.html#aa0028b509f43537b814d395d972949a2":[2,0,0,0,0,49,80,5],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseContext.html#aa0028b509f43537b814d395d972949a2":[3,0,0,0,0,48,75,5],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseContext.html#ae976c0cfe7196e77a9319726ad747a79":[2,0,0,0,0,49,80,2],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseContext.html#ae976c0cfe7196e77a9319726ad747a79":[3,0,0,0,0,48,75,2],
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseContext.html#aec761c1c2e3e3a90d2da8627ee18b13a":[2,0,0,0,0,49,80,4],
 "interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseContext.html#aec761c1c2e3e3a90d2da8627ee18b13a":[3,0,0,0,0,48,75,4],
 "interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseEnvironment.html":[2,0,0,0,0,49,81],
 "interfacecom_1_1sun_1_1star_1_1sdb_1_1XDatabaseEnvironment.html":[3,0,0,0,0,48,76],
@@ -215,39 +249,5 @@ var NAVTREEINDEX80 =
 "interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#aeb041cefeadd8aedf4d6b22cd5cf2930":[3,0,0,0,0,48,98,9],
 "interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#aee7972fc941ba654881f7a9952003b1e":[2,0,0,0,0,49,103,0],
 "interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryComposer.html#aee7972fc941ba654881f7a9952003b1e":[3,0,0,0,0,48,98,0],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSubDocument.html":[2,0,0,0,0,49,108],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSubDocument.html":[3,0,0,0,0,48,103],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSubDocument.html#a90a244fd3f6a1f3232644b3da191036f":[2,0,0,0,0,49,108,2],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSubDocument.html#a90a244fd3f6a1f3232644b3da191036f":[3,0,0,0,0,48,103,2],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSubDocument.html#aa6fd9812948c428cf2ab82ed2dce29e6":[2,0,0,0,0,49,108,1],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSubDocument.html#aa6fd9812948c428cf2ab82ed2dce29e6":[3,0,0,0,0,48,103,1],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSubDocument.html#ab78d3b9d2bc4fd5d06c876a91c355790":[2,0,0,0,0,49,108,0],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSubDocument.html#ab78d3b9d2bc4fd5d06c876a91c355790":[3,0,0,0,0,48,103,0],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSubDocument.html#af5d1fdcbfe78592afb590a4c244acf20":[2,0,0,0,0,49,108,3],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSubDocument.html#af5d1fdcbfe78592afb590a4c244acf20":[3,0,0,0,0,48,103,3],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XTextConnectionSettings.html":[2,0,0,0,0,49,109],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XTextConnectionSettings.html":[3,0,0,0,0,48,104],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XTextConnectionSettings.html#a9336f9ed0f791fc54a3434d1513b43c2":[2,0,0,0,0,49,109,1],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XTextConnectionSettings.html#a9336f9ed0f791fc54a3434d1513b43c2":[3,0,0,0,0,48,104,1],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XTextConnectionSettings.html#ae6872c0d73362de7c3f167030e03e1cf":[2,0,0,0,0,49,109,0],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1XTextConnectionSettings.html#ae6872c0d73362de7c3f167030e03e1cf":[3,0,0,0,0,48,104,0],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableListener.html":[2,0,0,0,0,49,0,8],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableListener.html":[3,0,0,0,0,48,0,4],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableListener.html#a20e940f595bb24c754d79bed12cee368":[2,0,0,0,0,49,0,8,1],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableListener.html#a20e940f595bb24c754d79bed12cee368":[3,0,0,0,0,48,0,4,1],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableListener.html#a832ae89401787eb2ed9a74ddb1712796":[2,0,0,0,0,49,0,8,0],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableListener.html#a832ae89401787eb2ed9a74ddb1712796":[3,0,0,0,0,48,0,4,0],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableListener.html#afba7967997aba9b31d8f8a4f14c2c86b":[2,0,0,0,0,49,0,8,2],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableListener.html#afba7967997aba9b31d8f8a4f14c2c86b":[3,0,0,0,0,48,0,4,2],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableWizard.html":[2,0,0,0,0,49,0,9],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableWizard.html":[3,0,0,0,0,48,0,5],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableWizard.html#a3feceb27ed78c6e0fab89a2f39c564e0":[2,0,0,0,0,49,0,9,3],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableWizard.html#a3feceb27ed78c6e0fab89a2f39c564e0":[3,0,0,0,0,48,0,5,3],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableWizard.html#a65e03964b2b370da577e463dcddd17a0":[2,0,0,0,0,49,0,9,5],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableWizard.html#a65e03964b2b370da577e463dcddd17a0":[3,0,0,0,0,48,0,5,5],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableWizard.html#a7fd73c114d52e6c73010adf1332f52b0":[2,0,0,0,0,49,0,9,0],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableWizard.html#a7fd73c114d52e6c73010adf1332f52b0":[3,0,0,0,0,48,0,5,0],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableWizard.html#a89aa865957cd8646ea69caee0ac4700c":[2,0,0,0,0,49,0,9,2],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableWizard.html#a89aa865957cd8646ea69caee0ac4700c":[3,0,0,0,0,48,0,5,2],
-"interfacecom_1_1sun_1_1star_1_1sdb_1_1application_1_1XCopyTableWizard.html#a9b80b758c3ce1307626b5924a87fdeb0":[2,0,0,0,0,49,0,9,1]
+"interfacecom_1_1sun_1_1star_1_1sdb_1_1XSubDocument.html":[2,0,0,0,0,49,108]
 };
