@@ -1,5 +1,45 @@
 var NAVTREEINDEX96 =
 {
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XImageManager.html#aeb4ee5d988bfa7fa7deee4591ffc5000":[3,0,0,0,0,63,44,5],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XImageManager.html#afaa3cd57db7ee0e86dcda10b46d84b35":[2,0,0,0,0,64,49,1],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XImageManager.html#afaa3cd57db7ee0e86dcda10b46d84b35":[3,0,0,0,0,63,44,1],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XImageManager.html#affe8ef6c7d1653b20260774276d31511":[2,0,0,0,0,64,49,0],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XImageManager.html#affe8ef6c7d1653b20260774276d31511":[3,0,0,0,0,63,44,0],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager.html":[2,0,0,0,0,64,50],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager.html":[3,0,0,0,0,63,45],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager.html#a0ad89cf184ebcce88103acc3066b5e83":[2,0,0,0,0,64,50,1],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager.html#a0ad89cf184ebcce88103acc3066b5e83":[3,0,0,0,0,63,45,1],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager.html#a915c34e0bf5b20f1ac688cdada67c9bc":[2,0,0,0,0,64,50,0],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager.html#a915c34e0bf5b20f1ac688cdada67c9bc":[3,0,0,0,0,63,45,0],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager2.html":[2,0,0,0,0,64,51],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager2.html":[3,0,0,0,0,63,46],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager2.html#a40a867ecef8a21f8a5bb75dd8dd7ca0f":[2,0,0,0,0,64,51,0],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager2.html#a40a867ecef8a21f8a5bb75dd8dd7ca0f":[3,0,0,0,0,63,46,0],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager2.html#a66f77c522e4e328f0a1aac36178a15d8":[2,0,0,0,0,64,51,2],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager2.html#a66f77c522e4e328f0a1aac36178a15d8":[3,0,0,0,0,63,46,2],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager2.html#abec5cc3bee5872b28b2a24c71f43e7b3":[2,0,0,0,0,64,51,1],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager2.html#abec5cc3bee5872b28b2a24c71f43e7b3":[3,0,0,0,0,63,46,1],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager2.html#ac1a7e1ab4e94510b0641be5210e10984":[2,0,0,0,0,64,51,4],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager2.html#ac1a7e1ab4e94510b0641be5210e10984":[3,0,0,0,0,63,46,4],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager2.html#ad1b90c5de347fb7e4bed4c4f151d9491":[2,0,0,0,0,64,51,3],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManager2.html#ad1b90c5de347fb7e4bed4c4f151d9491":[3,0,0,0,0,63,46,3],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManagerSupplier.html":[2,0,0,0,0,64,52],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManagerSupplier.html":[3,0,0,0,0,63,47],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManagerSupplier.html#ac5be5ea54f9c1526ff2f1459eec77f46":[2,0,0,0,0,64,52,0],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XModuleUIConfigurationManagerSupplier.html#ac5be5ea54f9c1526ff2f1459eec77f46":[3,0,0,0,0,63,47,0],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XPanel.html":[2,0,0,0,0,64,53],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XPanel.html":[3,0,0,0,0,63,48],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XPanel.html#a2d9d41c98db2777216f2b2c576ee900a":[2,0,0,0,0,64,53,9],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XPanel.html#a2d9d41c98db2777216f2b2c576ee900a":[3,0,0,0,0,63,48,9],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XPanel.html#a486267210dfc8118e23e6b1bc6090286":[2,0,0,0,0,64,53,7],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XPanel.html#a486267210dfc8118e23e6b1bc6090286":[3,0,0,0,0,63,48,7],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XPanel.html#a5883ecc0c5ecdb7129b2dfbee64e4828":[2,0,0,0,0,64,53,0],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XPanel.html#a5883ecc0c5ecdb7129b2dfbee64e4828":[3,0,0,0,0,63,48,0],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XPanel.html#a6985525dc4968dd01a335094cfe2c7cd":[2,0,0,0,0,64,53,12],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XPanel.html#a6985525dc4968dd01a335094cfe2c7cd":[3,0,0,0,0,63,48,12],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XPanel.html#a75e03afeaf9e13a6399279ed36c0c59f":[2,0,0,0,0,64,53,10],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XPanel.html#a75e03afeaf9e13a6399279ed36c0c59f":[3,0,0,0,0,63,48,10],
+"interfacecom_1_1sun_1_1star_1_1ui_1_1XPanel.html#a775e71d1ab52709b1058c1b3e32a2878":[2,0,0,0,0,64,53,5],
 "interfacecom_1_1sun_1_1star_1_1ui_1_1XPanel.html#a775e71d1ab52709b1058c1b3e32a2878":[3,0,0,0,0,63,48,5],
 "interfacecom_1_1sun_1_1star_1_1ui_1_1XPanel.html#a7d10a0dc365d9405ba172acf2b1d797b":[2,0,0,0,0,64,53,11],
 "interfacecom_1_1sun_1_1star_1_1ui_1_1XPanel.html#a7d10a0dc365d9405ba172acf2b1d797b":[3,0,0,0,0,63,48,11],
@@ -209,45 +249,5 @@ var NAVTREEINDEX96 =
 "interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlAccess.html":[3,0,0,0,0,63,0,9],
 "interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlAccess.html#ad4c9f2dab2a5beb5a24d391aa959a469":[2,0,0,0,0,64,1,18,0],
 "interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlAccess.html#ad4c9f2dab2a5beb5a24d391aa959a469":[3,0,0,0,0,63,0,9,0],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlAccess.html#ad8ee291a4d3b13b9abcf677269d387f2":[2,0,0,0,0,64,1,18,1],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlAccess.html#ad8ee291a4d3b13b9abcf677269d387f2":[3,0,0,0,0,63,0,9,1],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlInformation.html":[2,0,0,0,0,64,1,19],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlInformation.html":[3,0,0,0,0,63,0,10],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlInformation.html#a2de555d1ae060bae741e5ac85fd6b656":[2,0,0,0,0,64,1,19,0],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlInformation.html#a2de555d1ae060bae741e5ac85fd6b656":[3,0,0,0,0,63,0,10,0],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlInformation.html#a578b172a99c06aafe543dcea40c236b8":[2,0,0,0,0,64,1,19,3],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlInformation.html#a578b172a99c06aafe543dcea40c236b8":[3,0,0,0,0,63,0,10,3],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlInformation.html#a5f74c417679007b442bbcfb488bc57f4":[2,0,0,0,0,64,1,19,2],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlInformation.html#a5f74c417679007b442bbcfb488bc57f4":[3,0,0,0,0,63,0,10,2],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlInformation.html#af1b2741f66bae2948632b88accddfc05":[2,0,0,0,0,64,1,19,1],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlInformation.html#af1b2741f66bae2948632b88accddfc05":[3,0,0,0,0,63,0,10,1],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XDialogClosedListener.html":[2,0,0,0,0,64,1,20],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XDialogClosedListener.html":[3,0,0,0,0,63,0,11],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XDialogClosedListener.html#af09e15128ac384291d08ca9d3e59e0cf":[2,0,0,0,0,64,1,20,0],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XDialogClosedListener.html#af09e15128ac384291d08ca9d3e59e0cf":[3,0,0,0,0,63,0,11,0],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XExecutableDialog.html":[2,0,0,0,0,64,1,21],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XExecutableDialog.html":[3,0,0,0,0,63,0,12],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XExecutableDialog.html#a8c95aa3c564bb0fbe56397dd8a7a4334":[2,0,0,0,0,64,1,21,0],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XExecutableDialog.html#a8c95aa3c564bb0fbe56397dd8a7a4334":[3,0,0,0,0,63,0,12,0],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XExecutableDialog.html#aca5c2f3cad20ca2b6fd12d7a46def4f8":[2,0,0,0,0,64,1,21,1],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XExecutableDialog.html#aca5c2f3cad20ca2b6fd12d7a46def4f8":[3,0,0,0,0,63,0,12,1],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker.html":[2,0,0,0,0,64,1,22],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker.html":[3,0,0,0,0,63,0,13],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker.html#a5a7290ea4259a6716996cb3af919a565":[2,0,0,0,0,64,1,22,0],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker.html#a5a7290ea4259a6716996cb3af919a565":[3,0,0,0,0,63,0,13,0],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker.html#a646254bf23072a0e9253e769b0088769":[2,0,0,0,0,64,1,22,3],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker.html#a646254bf23072a0e9253e769b0088769":[3,0,0,0,0,63,0,13,3],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker.html#aa2b6845a85d78e0e9bceed2fc365abe1":[2,0,0,0,0,64,1,22,2],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker.html#aa2b6845a85d78e0e9bceed2fc365abe1":[3,0,0,0,0,63,0,13,2],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker.html#acb28e7a2cbef8b6f7680ee01f77e1efb":[2,0,0,0,0,64,1,22,4],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker.html#acb28e7a2cbef8b6f7680ee01f77e1efb":[3,0,0,0,0,63,0,13,4],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker.html#ae368e8b36ffdb8f8f7ba45d93556a60d":[2,0,0,0,0,64,1,22,1],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker.html#ae368e8b36ffdb8f8f7ba45d93556a60d":[3,0,0,0,0,63,0,13,1],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker2.html":[2,0,0,0,0,64,1,23],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker2.html":[3,0,0,0,0,63,0,14],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker2.html#abbb5db0cde90d998d17ad665eb8c9a51":[2,0,0,0,0,64,1,23,0],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker2.html#abbb5db0cde90d998d17ad665eb8c9a51":[3,0,0,0,0,63,0,14,0],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker3.html":[2,0,0,0,0,64,1,24],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker3.html":[3,0,0,0,0,63,0,15],
-"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker3.html#a285ead554b08e7e37ca2be418f412e73":[2,0,0,0,0,64,1,24,5]
+"interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XControlAccess.html#ad8ee291a4d3b13b9abcf677269d387f2":[2,0,0,0,0,64,1,18,1]
 };
