@@ -1,5 +1,47 @@
 var NAVTREEINDEX98 =
 {
+"interfacecom_1_1sun_1_1star_1_1uno_1_1XReference.html":[3,0,0,0,0,64,12],
+"interfacecom_1_1sun_1_1star_1_1uno_1_1XReference.html#ab953e90edb69534eb052f9064f6b40e9":[2,0,0,0,0,65,12,0],
+"interfacecom_1_1sun_1_1star_1_1uno_1_1XReference.html#ab953e90edb69534eb052f9064f6b40e9":[3,0,0,0,0,64,12,0],
+"interfacecom_1_1sun_1_1star_1_1uno_1_1XUnloadingPreference.html":[2,0,0,0,0,65,13],
+"interfacecom_1_1sun_1_1star_1_1uno_1_1XUnloadingPreference.html":[3,0,0,0,0,64,13],
+"interfacecom_1_1sun_1_1star_1_1uno_1_1XUnloadingPreference.html#a142a3ce59097e4487fdb84f090283399":[2,0,0,0,0,65,13,0],
+"interfacecom_1_1sun_1_1star_1_1uno_1_1XUnloadingPreference.html#a142a3ce59097e4487fdb84f090283399":[3,0,0,0,0,64,13,0],
+"interfacecom_1_1sun_1_1star_1_1uno_1_1XWeak.html":[2,0,0,0,0,65,14],
+"interfacecom_1_1sun_1_1star_1_1uno_1_1XWeak.html":[3,0,0,0,0,64,14],
+"interfacecom_1_1sun_1_1star_1_1uno_1_1XWeak.html#aed6d4b2c4e8b525ab98b475609940ed4":[2,0,0,0,0,65,14,0],
+"interfacecom_1_1sun_1_1star_1_1uno_1_1XWeak.html#aed6d4b2c4e8b525ab98b475609940ed4":[3,0,0,0,0,64,14,0],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XExternalUriReferenceTranslator.html":[2,0,0,0,0,66,5],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XExternalUriReferenceTranslator.html":[3,0,0,0,0,65,5],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XExternalUriReferenceTranslator.html#aa2661e263cb2113bae68a735deecb843":[2,0,0,0,0,66,5,0],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XExternalUriReferenceTranslator.html#aa2661e263cb2113bae68a735deecb843":[3,0,0,0,0,65,5,0],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XExternalUriReferenceTranslator.html#aa4e9118d6eca0d0cc89ef32d77ad847d":[2,0,0,0,0,66,5,1],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XExternalUriReferenceTranslator.html#aa4e9118d6eca0d0cc89ef32d77ad847d":[3,0,0,0,0,65,5,1],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html":[2,0,0,0,0,66,6],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html":[3,0,0,0,0,65,6],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a0c38e1584813d801655f7ca47c2ada31":[2,0,0,0,0,66,6,13],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a0c38e1584813d801655f7ca47c2ada31":[3,0,0,0,0,65,6,13],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a12214008d32f51e4b1fe3d036342c600":[2,0,0,0,0,66,6,4],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a12214008d32f51e4b1fe3d036342c600":[3,0,0,0,0,65,6,4],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a19342610084f1fc67fed97a3417aee27":[2,0,0,0,0,66,6,3],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a19342610084f1fc67fed97a3417aee27":[3,0,0,0,0,65,6,3],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a252676b7ad979e08790da6bad0bd6a0f":[2,0,0,0,0,66,6,5],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a252676b7ad979e08790da6bad0bd6a0f":[3,0,0,0,0,65,6,5],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a25e1070f8151d04e94e86ba9d9c0fbbe":[2,0,0,0,0,66,6,14],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a25e1070f8151d04e94e86ba9d9c0fbbe":[3,0,0,0,0,65,6,14],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a455d0bf3e29cda482a74e6eda2aeb595":[2,0,0,0,0,66,6,8],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a455d0bf3e29cda482a74e6eda2aeb595":[3,0,0,0,0,65,6,8],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a4df91a190354e3d10fd7937a9760b8eb":[2,0,0,0,0,66,6,16],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a4df91a190354e3d10fd7937a9760b8eb":[3,0,0,0,0,65,6,16],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a4f8b7da625a9bca7243016a23b9e3683":[2,0,0,0,0,66,6,15],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a4f8b7da625a9bca7243016a23b9e3683":[3,0,0,0,0,65,6,15],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a5864960512a9c5ec902f4e4fca4a9143":[2,0,0,0,0,66,6,0],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a5864960512a9c5ec902f4e4fca4a9143":[3,0,0,0,0,65,6,0],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a5c89f471e45e83b7431cf57eaef7e063":[2,0,0,0,0,66,6,2],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a5c89f471e45e83b7431cf57eaef7e063":[3,0,0,0,0,65,6,2],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a932f1d0a22df8bb3efce62edb813ff10":[2,0,0,0,0,66,6,12],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a932f1d0a22df8bb3efce62edb813ff10":[3,0,0,0,0,65,6,12],
+"interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a98595cdf7523fc050c0caf8fa978753a":[2,0,0,0,0,66,6,9],
 "interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#a98595cdf7523fc050c0caf8fa978753a":[3,0,0,0,0,65,6,9],
 "interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#ab84e57f742a9c5300c99752e2df26830":[2,0,0,0,0,66,6,10],
 "interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReference.html#ab84e57f742a9c5300c99752e2df26830":[3,0,0,0,0,65,6,10],
@@ -207,47 +249,5 @@ var NAVTREEINDEX98 =
 "interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#a1d8257d19ae9bd4fc74d14c8273cdd49":[3,0,0,0,0,66,75,0],
 "interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#a31238f496ee1c4db5082de94fbc17325":[2,0,0,0,0,67,80,2],
 "interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#a31238f496ee1c4db5082de94fbc17325":[3,0,0,0,0,66,75,2],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#a7253801f8925fca60eaab345a857b7ba":[2,0,0,0,0,67,80,4],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#a7253801f8925fca60eaab345a857b7ba":[3,0,0,0,0,66,75,4],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#a76d85f2ad9c38409ee4fbb4b7d44eddd":[2,0,0,0,0,67,80,6],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#a76d85f2ad9c38409ee4fbb4b7d44eddd":[3,0,0,0,0,66,75,6],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#a9b412b5a4b25423338487705fad6445b":[2,0,0,0,0,67,80,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#a9b412b5a4b25423338487705fad6445b":[3,0,0,0,0,66,75,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#aa3cf82ea05a2bdcd0b0ccbae007557f5":[2,0,0,0,0,67,80,7],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#aa3cf82ea05a2bdcd0b0ccbae007557f5":[3,0,0,0,0,66,75,7],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#ae68d54e4aa178e2cc1fb7f571a07f2cf":[2,0,0,0,0,67,80,5],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#ae68d54e4aa178e2cc1fb7f571a07f2cf":[3,0,0,0,0,66,75,5],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#aebe63b041d745e0a4e4d9b979fb8acc1":[2,0,0,0,0,67,80,3],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#aebe63b041d745e0a4e4d9b979fb8acc1":[3,0,0,0,0,66,75,3],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html":[2,0,0,0,0,67,81],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html":[3,0,0,0,0,66,76],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html#a9278be8203e1c42e2619179882ae4403":[2,0,0,0,0,67,81,2],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html#a9278be8203e1c42e2619179882ae4403":[3,0,0,0,0,66,76,2],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html#aa81aed607133209dade63a226818224d":[2,0,0,0,0,67,81,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html#aa81aed607133209dade63a226818224d":[3,0,0,0,0,66,76,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html#aabb9769f356ca5f930fc3130d4b3cccb":[2,0,0,0,0,67,81,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html#aabb9769f356ca5f930fc3130d4b3cccb":[3,0,0,0,0,66,76,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XMacroExpander.html":[2,0,0,0,0,67,82],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XMacroExpander.html":[3,0,0,0,0,66,77],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XMacroExpander.html#a50d503d828cb98e79e29caf7f8a4d717":[2,0,0,0,0,67,82,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XMacroExpander.html#a50d503d828cb98e79e29caf7f8a4d717":[3,0,0,0,0,66,77,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XMergeable.html":[2,0,0,0,0,67,83],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XMergeable.html":[3,0,0,0,0,66,78],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XMergeable.html#a3c5e397671edf1155afb0914f9406d74":[2,0,0,0,0,67,83,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XMergeable.html#a3c5e397671edf1155afb0914f9406d74":[3,0,0,0,0,66,78,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XMergeable.html#a7f4bac19e5378c78fa695325f32279ad":[2,0,0,0,0,67,83,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XMergeable.html#a7f4bac19e5378c78fa695325f32279ad":[3,0,0,0,0,66,78,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeApproveListener.html":[2,0,0,0,0,67,84],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeApproveListener.html":[3,0,0,0,0,66,79],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeApproveListener.html#aad86cb66e928b4f241dcb290b4bf1738":[2,0,0,0,0,67,84,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeApproveListener.html#aad86cb66e928b4f241dcb290b4bf1738":[3,0,0,0,0,66,79,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html":[2,0,0,0,0,67,85],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html":[3,0,0,0,0,66,80],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#a2d1ab60d06e1770cd1554613347ae991":[2,0,0,0,0,67,85,3],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#a2d1ab60d06e1770cd1554613347ae991":[3,0,0,0,0,66,80,3],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#a36735acc4e4514dec742b8992de5e83f":[2,0,0,0,0,67,85,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#a36735acc4e4514dec742b8992de5e83f":[3,0,0,0,0,66,80,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#aa722646a829ee16e632d1b3ef5e6fe6f":[2,0,0,0,0,67,85,2],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#aa722646a829ee16e632d1b3ef5e6fe6f":[3,0,0,0,0,66,80,2],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#aa941e5eab44274eb697756310fb21a18":[2,0,0,0,0,67,85,1]
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#a7253801f8925fca60eaab345a857b7ba":[2,0,0,0,0,67,80,4]
 };
