@@ -1,5 +1,47 @@
 var NAVTREEINDEX99 =
 {
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#a7253801f8925fca60eaab345a857b7ba":[3,0,0,0,0,66,75,4],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#a76d85f2ad9c38409ee4fbb4b7d44eddd":[2,0,0,0,0,67,80,6],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#a76d85f2ad9c38409ee4fbb4b7d44eddd":[3,0,0,0,0,66,75,6],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#a9b412b5a4b25423338487705fad6445b":[2,0,0,0,0,67,80,1],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#a9b412b5a4b25423338487705fad6445b":[3,0,0,0,0,66,75,1],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#aa3cf82ea05a2bdcd0b0ccbae007557f5":[2,0,0,0,0,67,80,7],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#aa3cf82ea05a2bdcd0b0ccbae007557f5":[3,0,0,0,0,66,75,7],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#ae68d54e4aa178e2cc1fb7f571a07f2cf":[2,0,0,0,0,67,80,5],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#ae68d54e4aa178e2cc1fb7f571a07f2cf":[3,0,0,0,0,66,75,5],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#aebe63b041d745e0a4e4d9b979fb8acc1":[2,0,0,0,0,67,80,3],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLocalizedAliases.html#aebe63b041d745e0a4e4d9b979fb8acc1":[3,0,0,0,0,66,75,3],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html":[2,0,0,0,0,67,81],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html":[3,0,0,0,0,66,76],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html#a9278be8203e1c42e2619179882ae4403":[2,0,0,0,0,67,81,2],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html#a9278be8203e1c42e2619179882ae4403":[3,0,0,0,0,66,76,2],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html#aa81aed607133209dade63a226818224d":[2,0,0,0,0,67,81,1],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html#aa81aed607133209dade63a226818224d":[3,0,0,0,0,66,76,1],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html#aabb9769f356ca5f930fc3130d4b3cccb":[2,0,0,0,0,67,81,0],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XLockable.html#aabb9769f356ca5f930fc3130d4b3cccb":[3,0,0,0,0,66,76,0],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XMacroExpander.html":[2,0,0,0,0,67,82],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XMacroExpander.html":[3,0,0,0,0,66,77],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XMacroExpander.html#a50d503d828cb98e79e29caf7f8a4d717":[2,0,0,0,0,67,82,0],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XMacroExpander.html#a50d503d828cb98e79e29caf7f8a4d717":[3,0,0,0,0,66,77,0],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XMergeable.html":[2,0,0,0,0,67,83],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XMergeable.html":[3,0,0,0,0,66,78],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XMergeable.html#a3c5e397671edf1155afb0914f9406d74":[2,0,0,0,0,67,83,1],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XMergeable.html#a3c5e397671edf1155afb0914f9406d74":[3,0,0,0,0,66,78,1],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XMergeable.html#a7f4bac19e5378c78fa695325f32279ad":[2,0,0,0,0,67,83,0],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XMergeable.html#a7f4bac19e5378c78fa695325f32279ad":[3,0,0,0,0,66,78,0],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeApproveListener.html":[2,0,0,0,0,67,84],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeApproveListener.html":[3,0,0,0,0,66,79],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeApproveListener.html#aad86cb66e928b4f241dcb290b4bf1738":[2,0,0,0,0,67,84,0],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeApproveListener.html#aad86cb66e928b4f241dcb290b4bf1738":[3,0,0,0,0,66,79,0],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html":[2,0,0,0,0,67,85],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html":[3,0,0,0,0,66,80],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#a2d1ab60d06e1770cd1554613347ae991":[2,0,0,0,0,67,85,3],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#a2d1ab60d06e1770cd1554613347ae991":[3,0,0,0,0,66,80,3],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#a36735acc4e4514dec742b8992de5e83f":[2,0,0,0,0,67,85,0],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#a36735acc4e4514dec742b8992de5e83f":[3,0,0,0,0,66,80,0],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#aa722646a829ee16e632d1b3ef5e6fe6f":[2,0,0,0,0,67,85,2],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#aa722646a829ee16e632d1b3ef5e6fe6f":[3,0,0,0,0,66,80,2],
+"interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#aa941e5eab44274eb697756310fb21a18":[2,0,0,0,0,67,85,1],
 "interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeBroadcaster.html#aa941e5eab44274eb697756310fb21a18":[3,0,0,0,0,66,80,1],
 "interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeListener.html":[2,0,0,0,0,67,86],
 "interfacecom_1_1sun_1_1star_1_1util_1_1XModeChangeListener.html":[3,0,0,0,0,66,81],
@@ -207,47 +249,5 @@ var NAVTREEINDEX99 =
 "interfacecom_1_1sun_1_1star_1_1util_1_1XRefreshable.html#afba35ac103d79954de9e0b5c8b516802":[3,0,0,0,0,66,97,0],
 "interfacecom_1_1sun_1_1star_1_1util_1_1XReplaceDescriptor.html":[2,0,0,0,0,67,105],
 "interfacecom_1_1sun_1_1star_1_1util_1_1XReplaceDescriptor.html":[3,0,0,0,0,66,100],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XReplaceDescriptor.html#a57ae9601b5f57f95deec6a4b0d733c1c":[2,0,0,0,0,67,105,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XReplaceDescriptor.html#a57ae9601b5f57f95deec6a4b0d733c1c":[3,0,0,0,0,66,100,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XReplaceDescriptor.html#ac588fdbf6be68d94955332859b1f1c15":[2,0,0,0,0,67,105,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XReplaceDescriptor.html#ac588fdbf6be68d94955332859b1f1c15":[3,0,0,0,0,66,100,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XReplaceable.html":[2,0,0,0,0,67,104],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XReplaceable.html":[3,0,0,0,0,66,99],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XReplaceable.html#a2ae9b8c93c455759f0d02ea26b31c74e":[2,0,0,0,0,67,104,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XReplaceable.html#a2ae9b8c93c455759f0d02ea26b31c74e":[3,0,0,0,0,66,99,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XReplaceable.html#a34a0101150060d8d8a1de574e3f5426f":[2,0,0,0,0,67,104,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XReplaceable.html#a34a0101150060d8d8a1de574e3f5426f":[3,0,0,0,0,66,99,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSearchDescriptor.html":[2,0,0,0,0,67,107],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSearchDescriptor.html":[3,0,0,0,0,66,102],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSearchDescriptor.html#a9d36d192be4f42c172f00b180a9f00f3":[2,0,0,0,0,67,107,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSearchDescriptor.html#a9d36d192be4f42c172f00b180a9f00f3":[3,0,0,0,0,66,102,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSearchDescriptor.html#adf50920186a0ffca0b85b9e7e26b1462":[2,0,0,0,0,67,107,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSearchDescriptor.html#adf50920186a0ffca0b85b9e7e26b1462":[3,0,0,0,0,66,102,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSearchable.html":[2,0,0,0,0,67,106],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSearchable.html":[3,0,0,0,0,66,101],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSearchable.html#a2a2a03764c9b5f8b7ebb25505b791f08":[2,0,0,0,0,67,106,2],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSearchable.html#a2a2a03764c9b5f8b7ebb25505b791f08":[3,0,0,0,0,66,101,2],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSearchable.html#a5e7b729c2d45dea6fa517b96e4e3feea":[2,0,0,0,0,67,106,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSearchable.html#a5e7b729c2d45dea6fa517b96e4e3feea":[3,0,0,0,0,66,101,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSearchable.html#a98efb20b2bcd591e8d78a559c737cdfa":[2,0,0,0,0,67,106,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSearchable.html#a98efb20b2bcd591e8d78a559c737cdfa":[3,0,0,0,0,66,101,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSearchable.html#ad02729bd46ce71ee5973e5dfbb39f5d5":[2,0,0,0,0,67,106,3],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSearchable.html#ad02729bd46ce71ee5973e5dfbb39f5d5":[3,0,0,0,0,66,101,3],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSortable.html":[2,0,0,0,0,67,108],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSortable.html":[3,0,0,0,0,66,103],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSortable.html#a998caad616c6341c18251b2eed573960":[2,0,0,0,0,67,108,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSortable.html#a998caad616c6341c18251b2eed573960":[3,0,0,0,0,66,103,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSortable.html#aea3c825a7519911901218e5e8601cf88":[2,0,0,0,0,67,108,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XSortable.html#aea3c825a7519911901218e5e8601cf88":[3,0,0,0,0,66,103,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XStringAbbreviation.html":[2,0,0,0,0,67,109],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XStringAbbreviation.html":[3,0,0,0,0,66,104],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XStringAbbreviation.html#ac5ac0e1f472e69cd5fafe1c600f7ef17":[2,0,0,0,0,67,109,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XStringAbbreviation.html#ac5ac0e1f472e69cd5fafe1c600f7ef17":[3,0,0,0,0,66,104,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XStringEscape.html":[2,0,0,0,0,67,110],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XStringEscape.html":[3,0,0,0,0,66,105],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XStringEscape.html#aac865164209f1f7011a9a6ce5e838692":[2,0,0,0,0,67,110,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XStringEscape.html#aac865164209f1f7011a9a6ce5e838692":[3,0,0,0,0,66,105,0],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XStringEscape.html#af154197697885754f4ccb6714f1cfa48":[2,0,0,0,0,67,110,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XStringEscape.html#af154197697885754f4ccb6714f1cfa48":[3,0,0,0,0,66,105,1],
-"interfacecom_1_1sun_1_1star_1_1util_1_1XStringMapping.html":[2,0,0,0,0,67,111]
+"interfacecom_1_1sun_1_1star_1_1util_1_1XReplaceDescriptor.html#a57ae9601b5f57f95deec6a4b0d733c1c":[2,0,0,0,0,67,105,1]
 };
