@@ -71,9 +71,9 @@ var searchData=
   ['sessionmanager_2eidl_68',['SessionManager.idl',['../SessionManager_8idl.html',1,'']]],
   ['setaccess_2eidl_69',['SetAccess.idl',['../SetAccess_8idl.html',1,'']]],
   ['setelement_2eidl_70',['SetElement.idl',['../SetElement_8idl.html',1,'']]],
-  ['setexpression_2eidl_71',['SetExpression.idl',['../textfield_2SetExpression_8idl.html',1,'(Global Namespace)'],['../fieldmaster_2SetExpression_8idl.html',1,'(Global Namespace)']]],
+  ['setexpression_2eidl_71',['SetExpression.idl',['../fieldmaster_2SetExpression_8idl.html',1,'(Global Namespace)'],['../textfield_2SetExpression_8idl.html',1,'(Global Namespace)']]],
   ['setpropertytolerantfailed_2eidl_72',['SetPropertyTolerantFailed.idl',['../SetPropertyTolerantFailed_8idl.html',1,'']]],
-  ['settings_2eidl_73',['Settings.idl',['../frame_2Settings_8idl.html',1,'(Global Namespace)'],['../document_2Settings_8idl.html',1,'(Global Namespace)']]],
+  ['settings_2eidl_73',['Settings.idl',['../document_2Settings_8idl.html',1,'(Global Namespace)'],['../frame_2Settings_8idl.html',1,'(Global Namespace)']]],
   ['setupdate_2eidl_74',['SetUpdate.idl',['../SetUpdate_8idl.html',1,'']]],
   ['setvariabletype_2eidl_75',['SetVariableType.idl',['../SetVariableType_8idl.html',1,'']]],
   ['shademode_2eidl_76',['ShadeMode.idl',['../ShadeMode_8idl.html',1,'']]],
@@ -191,31 +191,34 @@ var searchData=
   ['stringresourcewithlocation_2eidl_188',['StringResourceWithLocation.idl',['../StringResourceWithLocation_8idl.html',1,'']]],
   ['stringresourcewithstorage_2eidl_189',['StringResourceWithStorage.idl',['../StringResourceWithStorage_8idl.html',1,'']]],
   ['strokeattributes_2eidl_190',['StrokeAttributes.idl',['../StrokeAttributes_8idl.html',1,'']]],
-  ['style_2eidl_191',['Style.idl',['../awt_2Style_8idl.html',1,'(Global Namespace)'],['../style_2Style_8idl.html',1,'(Global Namespace)']]],
-  ['stylefamilies_2eidl_192',['StyleFamilies.idl',['../StyleFamilies_8idl.html',1,'']]],
-  ['stylefamily_2eidl_193',['StyleFamily.idl',['../StyleFamily_8idl.html',1,'']]],
-  ['subincrement_2eidl_194',['SubIncrement.idl',['../SubIncrement_8idl.html',1,'']]],
-  ['subject_2eidl_195',['Subject.idl',['../Subject_8idl.html',1,'']]],
-  ['submissionpropertyhandler_2eidl_196',['SubmissionPropertyHandler.idl',['../SubmissionPropertyHandler_8idl.html',1,'']]],
-  ['submitbutton_2eidl_197',['SubmitButton.idl',['../component_2SubmitButton_8idl.html',1,'(Global Namespace)'],['../control_2SubmitButton_8idl.html',1,'(Global Namespace)']]],
-  ['subtitleshape_2eidl_198',['SubtitleShape.idl',['../SubtitleShape_8idl.html',1,'']]],
-  ['subtotalcolumn_2eidl_199',['SubTotalColumn.idl',['../SubTotalColumn_8idl.html',1,'']]],
-  ['subtotaldescriptor_2eidl_200',['SubTotalDescriptor.idl',['../SubTotalDescriptor_8idl.html',1,'']]],
-  ['subtotalfield_2eidl_201',['SubTotalField.idl',['../SubTotalField_8idl.html',1,'']]],
-  ['subtotalfieldsenumeration_2eidl_202',['SubTotalFieldsEnumeration.idl',['../SubTotalFieldsEnumeration_8idl.html',1,'']]],
-  ['svgtools_2eidl_203',['SvgTools.idl',['../SvgTools_8idl.html',1,'']]],
-  ['symbol_2eidl_204',['Symbol.idl',['../Symbol_8idl.html',1,'']]],
-  ['symboldescriptor_2eidl_205',['SymbolDescriptor.idl',['../SymbolDescriptor_8idl.html',1,'']]],
-  ['symbolstyle_2eidl_206',['SymbolStyle.idl',['../SymbolStyle_8idl.html',1,'']]],
-  ['syncdbussessionhelper_2eidl_207',['SyncDbusSessionHelper.idl',['../SyncDbusSessionHelper_8idl.html',1,'']]],
-  ['synchronizepolicy_2eidl_208',['SynchronizePolicy.idl',['../SynchronizePolicy_8idl.html',1,'']]],
-  ['synchronousframeloader_2eidl_209',['SynchronousFrameLoader.idl',['../SynchronousFrameLoader_8idl.html',1,'']]],
-  ['systemclipboard_2eidl_210',['SystemClipboard.idl',['../SystemClipboard_8idl.html',1,'']]],
-  ['systemdependent_2eidl_211',['SystemDependent.idl',['../SystemDependent_8idl.html',1,'']]],
-  ['systemdependentxwindow_2eidl_212',['SystemDependentXWindow.idl',['../SystemDependentXWindow_8idl.html',1,'']]],
-  ['systemintegration_2eidl_213',['SystemIntegration.idl',['../SystemIntegration_8idl.html',1,'']]],
-  ['systempointer_2eidl_214',['SystemPointer.idl',['../SystemPointer_8idl.html',1,'']]],
-  ['systemshellexecute_2eidl_215',['SystemShellExecute.idl',['../SystemShellExecute_8idl.html',1,'']]],
-  ['systemshellexecuteexception_2eidl_216',['SystemShellExecuteException.idl',['../SystemShellExecuteException_8idl.html',1,'']]],
-  ['systemshellexecuteflags_2eidl_217',['SystemShellExecuteFlags.idl',['../SystemShellExecuteFlags_8idl.html',1,'']]]
+  ['struct_2eidl_191',['Struct.idl',['../Struct_8idl.html',1,'']]],
+  ['structlong_2eidl_192',['StructLong.idl',['../StructLong_8idl.html',1,'']]],
+  ['structstring_2eidl_193',['StructString.idl',['../StructString_8idl.html',1,'']]],
+  ['style_2eidl_194',['Style.idl',['../awt_2Style_8idl.html',1,'(Global Namespace)'],['../style_2Style_8idl.html',1,'(Global Namespace)']]],
+  ['stylefamilies_2eidl_195',['StyleFamilies.idl',['../StyleFamilies_8idl.html',1,'']]],
+  ['stylefamily_2eidl_196',['StyleFamily.idl',['../StyleFamily_8idl.html',1,'']]],
+  ['subincrement_2eidl_197',['SubIncrement.idl',['../SubIncrement_8idl.html',1,'']]],
+  ['subject_2eidl_198',['Subject.idl',['../Subject_8idl.html',1,'']]],
+  ['submissionpropertyhandler_2eidl_199',['SubmissionPropertyHandler.idl',['../SubmissionPropertyHandler_8idl.html',1,'']]],
+  ['submitbutton_2eidl_200',['SubmitButton.idl',['../component_2SubmitButton_8idl.html',1,'(Global Namespace)'],['../control_2SubmitButton_8idl.html',1,'(Global Namespace)']]],
+  ['subtitleshape_2eidl_201',['SubtitleShape.idl',['../SubtitleShape_8idl.html',1,'']]],
+  ['subtotalcolumn_2eidl_202',['SubTotalColumn.idl',['../SubTotalColumn_8idl.html',1,'']]],
+  ['subtotaldescriptor_2eidl_203',['SubTotalDescriptor.idl',['../SubTotalDescriptor_8idl.html',1,'']]],
+  ['subtotalfield_2eidl_204',['SubTotalField.idl',['../SubTotalField_8idl.html',1,'']]],
+  ['subtotalfieldsenumeration_2eidl_205',['SubTotalFieldsEnumeration.idl',['../SubTotalFieldsEnumeration_8idl.html',1,'']]],
+  ['svgtools_2eidl_206',['SvgTools.idl',['../SvgTools_8idl.html',1,'']]],
+  ['symbol_2eidl_207',['Symbol.idl',['../Symbol_8idl.html',1,'']]],
+  ['symboldescriptor_2eidl_208',['SymbolDescriptor.idl',['../SymbolDescriptor_8idl.html',1,'']]],
+  ['symbolstyle_2eidl_209',['SymbolStyle.idl',['../SymbolStyle_8idl.html',1,'']]],
+  ['syncdbussessionhelper_2eidl_210',['SyncDbusSessionHelper.idl',['../SyncDbusSessionHelper_8idl.html',1,'']]],
+  ['synchronizepolicy_2eidl_211',['SynchronizePolicy.idl',['../SynchronizePolicy_8idl.html',1,'']]],
+  ['synchronousframeloader_2eidl_212',['SynchronousFrameLoader.idl',['../SynchronousFrameLoader_8idl.html',1,'']]],
+  ['systemclipboard_2eidl_213',['SystemClipboard.idl',['../SystemClipboard_8idl.html',1,'']]],
+  ['systemdependent_2eidl_214',['SystemDependent.idl',['../SystemDependent_8idl.html',1,'']]],
+  ['systemdependentxwindow_2eidl_215',['SystemDependentXWindow.idl',['../SystemDependentXWindow_8idl.html',1,'']]],
+  ['systemintegration_2eidl_216',['SystemIntegration.idl',['../SystemIntegration_8idl.html',1,'']]],
+  ['systempointer_2eidl_217',['SystemPointer.idl',['../SystemPointer_8idl.html',1,'']]],
+  ['systemshellexecute_2eidl_218',['SystemShellExecute.idl',['../SystemShellExecute_8idl.html',1,'']]],
+  ['systemshellexecuteexception_2eidl_219',['SystemShellExecuteException.idl',['../SystemShellExecuteException_8idl.html',1,'']]],
+  ['systemshellexecuteflags_2eidl_220',['SystemShellExecuteFlags.idl',['../SystemShellExecuteFlags_8idl.html',1,'']]]
 ];
